Fourth Circuit Oral Argument Archive

Argument Date | Case Number | Case Name | Panel | Counsel
--- | --- | --- | --- | ---
5/15/2014 | 13-1033 | Colony Insurance Company v. Charles Peterson | Robert B. King, James A. Wynn, Jr., Henry F. Floyd | Reid Adams Jr.,Patrick Kane, James Bryan, Stephen Teague
5/15/2014 | 13-4933 | Under Seal v. US | J. Harvie Wilkinson III, Stephanie D. Thacker, Clyde H. Hamilton | Sujit Raman, Peter Ward
5/15/2014 | 12-4621 | US v. Ehizele Seignious | J. Harvie Wilkinson III, Stephanie D. Thacker, Clyde H. Hamilton | Arthur Cheslock, Tamera Fine
5/15/2014 | 12-5032 | US v. Raynauld Bradley, Jr. | Robert B. King, James A. Wynn, Jr., Henry F. Floyd | Arthur Cheslock, Kelly Hayes
5/15/2014 | 13-1480 | Brian Edward Reid v. Commissioner of Soc Sec | William B. Traxler, Jr., Paul V. Niemeyer, Allyson K. Duncan | Beatrice Whitten, Sarah Berry
5/15/2014 | 13-1696 | Priority Auto Group, Inc. v. Ford Motor Company | Roger L. Gregory, G. Steven Agee, Barbara Milano Keenan | Brad Weiss, Dominic Perella
5/15/2014 | 13-2112 | In re: Norfolk Southern | William B. Traxler, Jr., Paul V. Niemeyer, Allyson K. Duncan | Jonathan Walker, William Breit
5/15/2014 | 13-4177 | US v. Troy Chisolm | Roger L. Gregory, G. Steven Agee, Barbara Milano Keenan | Ann Walsh, Nathan Williams
5/15/2014 | 13-4280 | US v. Christopher Jamie Davis | Diana Gribbon Motz, Albert Diaz, Andre M. Davis | James Rogers, Robert Daley Jr.
5/15/2014 | 13-4316 | US v. David Anthony Taylor | J. Harvie Wilkinson III, Stephanie D. Thacker, Clyde H. Hamilton | Kari Jackson, Jean Hudson , Dennis Jones
5/15/2014 | 13-4335 | US v. Randal McLean | Robert B. King, James A. Wynn, Jr., Henry F. Floyd | William Mitchell Jr., John Purcell Jr.
5/15/2014 | 13-4768 | US v. Jose Valdovinos | Diana Gribbon Motz, Albert Diaz, Andre M. Davis | Ann Hester, Amy Ray
5/15/2014 | 13-4417 | US v. Alan Butler | Roger L. Gregory, G. Steven Agee, Barbara Milano Keenan | William Burgess IV, Jamie Mickelson
5/15/2014 | 13-4503 | US v. Harvey Mungro, Jr. | William B. Traxler, Jr., Paul V. Niemeyer, Allyson K. Duncan | Joshua Carpenter, Amy Ray
5/15/2014 | 13-4249 | US v. Jean Brown | Robert B. King, James A. Wynn, Jr., Henry F. Floyd | Gary Proctor, Peter Nothstein
5/15/2014 | 12-4886 | US v. David Parker | J. Harvie Wilkinson III, Stephanie D. Thacker, Clyde H. Hamilton | Michael Montemarano, Paul Nitze
5/14/2014 | 14-1189 | FLAME S.A. v. Freight Bulk Pte. Ltd. | J. Harvie Wilkinson III, G. Steven Agee, Albert Diaz | Charles Rothfeld, William Bennett III
5/14/2014 | 13-1940 | William Marshall v. James B. Nutter & Company | Paul V. Niemeyer, James A. Wynn, Jr., Robert J. Conrad, Jr. | Martin Wolf, Todd Ruskamp
5/14/2014 | 13-2050 | Southern Appalachian Mountain v. A & G Coal Corporation | J. Harvie Wilkinson III, G. Steven Agee, Albert Diaz | Allen Dudley Jr., Derek Teaney
5/14/2014 | 13-2131 | Denise Minter v. Wells Fargo Bank, N.A. | Paul V. Niemeyer, James A. Wynn, Jr., Robert J. Conrad, Jr. | Cyril Smith, William Jay
5/14/2014 | 13-4210 | US v. Bolarinwa Adeyale | J. Harvie Wilkinson III, G. Steven Agee, Albert Diaz | Robert Biddle, Margaret Moeser
5/14/2014 | 13-4663 | US v. Joseph Catone, Jr. | William B. Traxler, Jr., Barbara Milano Keenan, Henry F. Floyd | Joshua Carpenter, William Miller
5/14/2014 | 14-1158 | David King v. Kathleen Sebelius | Roger L. Gregory, Stephanie D. Thacker, Andre M. Davis | Michael Carvin, Stuart Delery, Stuart Raphael
5/14/2014 | 13-1869 | Bradley Petry v. Prosperity Mortgage Company | Paul V. Niemeyer, James A. Wynn, Jr., Robert J. Conrad, Jr. | Benjamin Carney, Irene Freidel, Jay Varon
5/14/2014 | 13-1700 | Maurice Meyer, III v. Carolyn Colvin | Diana Gribbon Motz, Robert B. King, Allyson K. Duncan | Robertson Wendt Jr., Jennifer Randall
5/14/2014 | 13-6407 | Edmund Goins v. Warden, Perry Correctional Ins | Roger L. Gregory, Stephanie D. Thacker, Andre M. Davis | Robert Dressel, James Mabry
5/14/2014 | 12-4560 | US v. Victor Martinez-Rivera | William B. Traxler, Jr., Barbara Milano Keenan, Henry F. Floyd | Joanna Silver, John Taddei
5/14/2014 | 13-1900 | Chandra Anand v. Ocwen Loan Servicing, LLC | Diana Gribbon Motz, Robert B. King, Allyson K. Duncan | Douglas Gottron, Joshua Tropper
5/14/2014 | 12-2329 | Tobia Quitanilla v. Eric Holder, Jr. | Diana Gribbon Motz, Robert B. King, Allyson K. Duncan | Sam Hasan, Edward Wiggers
5/14/2014 | 12-8096 | US v. Robert Hairston | Roger L. Gregory, Stephanie D. Thacker, Andre M. Davis | Stephanie Taylor, William Miller
5/14/2014 | 13-1007 | Robert Cherry, Jr. v. Mayor and City Council | William B. Traxler, Jr., Barbara Milano Keenan, Henry F. Floyd | James Ulwick, Charles Monk II, Robert Klausner
5/14/2014 | 13-1491 | Jorge Solomon-Membreno v. Eric Holder, Jr. | Paul V. Niemeyer, James A. Wynn, Jr., Robert J. Conrad, Jr. | Ivan Yacub, Liza Murcia
5/14/2014 | 13-1553 | Eastern Associated Coal Co. v. DOWCP | Roger L. Gregory, Stephanie D. Thacker, Andre M. Davis | Mark Solomons, Sarah Hurley
5/14/2014 | 13-1608 | National Heritage Foundation v. Highbourne Foundation | J. Harvie Wilkinson III, G. Steven Agee, Albert Diaz | David Goroff, Glenn Merrick
5/14/2014 | 13-1651 | Oscar De Leon v. Eric Holder, Jr. | Diana Gribbon Motz, Robert B. King, Allyson K. Duncan | Cherylle Corpuz, Jeffery Leist
5/13/2014 | 13-2215 | Defenders of Wildlife v. NC Dept of Transportation | Allyson K. Duncan, James A. Wynn, Jr., J. Michelle Childs | Julia Youngman, Robert Lundman, John Maddrey
5/13/2014 | 13-1597 | Wildon Cordova v. Eric Holder, Jr. | Diana Gribbon Motz, G. Steven Agee, Stephanie D. Thacker | Linda Dominguez, Anna Nelson
5/13/2014 | 13-0414 | EQT Production Company v. Robert Adair | J. Harvie Wilkinson III, Barbara Milano Keenan, Albert Diaz | Jonathan Blank, Michael Smith, Elizabeth Cabraser
5/13/2014 | 13-1265 | Paul Sartin v. McNair Law Firm PA | Paul V. Niemeyer, Roger L. Gregory, Henry F. Floyd | Ronald Richter Jr., Robert Stepp
5/13/2014 | 13-1389 | EEOC v. A.C. Widenhouse, Incorporated | Allyson K. Duncan, James A. Wynn, Jr., J. Michelle Childs | George Adams III, Jenny Sharpe, Julie Gantz
5/13/2014 | 13-1459 | Joseph Larosa v. Virgil Larosa | Paul V. Niemeyer, Roger L. Gregory, Henry F. Floyd | Paul Prados, Matthew Heiskell
5/13/2014 | 13-1495 | American Steamship Owners v. Dann Ocean Towing, Inc. | J. Harvie Wilkinson III, Barbara Milano Keenan, Albert Diaz | David Fromm, Allen von Spiegelfeld
5/13/2014 | 14-1167 | Timothy Bostic v. George Schaefer | Paul V. Niemeyer, Roger L. Gregory, Henry F. Floyd | David Oakley, David Nimocks, Theodore Olson, James Esseks, Stuart Raphael
5/13/2014 | 13-1828 | David Danser v. Patricia Stansberry | J. Harvie Wilkinson III, Barbara Milano Keenan, Albert Diaz | Michael James, Elizabeth Simpson
5/13/2014 | 13-1888 | Judy Moon v. BWX Technologies, Incorporated | Diana Gribbon Motz, G. Steven Agee, Stephanie D. Thacker | Sidney Kirstein, Joseph Rainsbury
5/13/2014 | 13-2011 | Mammar Ameur v. Robert Gates | William B. Traxler, Jr., Diana Gribbon Motz, G. Steven Agee | Gwynne Skinner, Sydney Foster
5/13/2014 | 13-2096 | Samuel Calderon v. GEICO General Insurance Co | William B. Traxler, Jr., Robert B. King, Andre M. Davis | Eric Hemmendinger, Matthew Morgan
5/13/2014 | 13-2200 | Lois Alt v. Chesapeake Bay Foundation | William B. Traxler, Jr., Robert B. King, Andre M. Davis | Jon Mueller, James Banks
5/13/2014 | 13-2419 | PPL EnergyPlus, LLC v. Douglas Nazarian | J. Harvie Wilkinson III, Barbara Milano Keenan, Albert Diaz | Scott Strauss, Clifton Elgarten , Paul Clement
5/13/2014 | 13-4378 | US v. Nader Modanlo | Robert B. King, Stephanie D. Thacker, Andre M. Davis | Samuel Dewey, Sujit Raman
5/13/2014 | 13-6446 | Anthony Mann v. C Failey | William B. Traxler, Jr., Robert B. King, Andre M. Davis | Adam Zurbriggen, Janet Holmes
5/13/2014 | 13-2037 | Patricia Hentosh v. Old Dominion University | Allyson K. Duncan, James A. Wynn, Jr., J. Michelle Childs | Raymond Hogge Jr., George Norris Jr.
5/13/2014 | 13-2044 | McAirlaids, Inc. v. Kimberly-Clark Corporation | Allyson K. Duncan, James A. Wynn, Jr., J. Michelle Childs | Frank Friedman, Andrew Klevorn
4/11/2014 | 13-1821 | James Scheider, Jr. v. Deutsche Bank National Trust | Diana Gribbon Motz, Albert Diaz, Henry F. Floyd | Antonia Lucia, Roberts Vaux, Jeffrey Anderson
4/11/2014 | 13-0004 | Elrico Fowler v. Carlton Joyner | William B. Traxler, Jr., Allyson K. Duncan, Andre M. Davis | Mark Pickett, Sonya Calloway-Durham
4/11/2014 | 12-4522 | US v. Alton Benn | Robert B. King, Roger L. Gregory, Stephanie D. Thacker | Sandra Barrett , Robert McClellan, John Fischer, Thomas Johnson Jr., Lisa Boggs, Stephen Inman
4/11/2014 | 12-2357 | Diane Russell v. Absolute Collection Services | Diana Gribbon Motz, Albert Diaz, Henry F. Floyd | Sean Partrick, Deepak Gupta
4/11/2014 | 13-2135 | Flying Pigs, LLC v. RRAJ Franchising, LLC | Robert B. King, Roger L. Gregory, Stephanie D. Thacker | Ernest Evans, Gavin Reardon
3/26/2014 | 13-6576 | Baxter Vinson v. Alan Walls | William B. Traxler, Jr., Henry F. Floyd, Clyde H. Hamilton | Andrew Lindemann, James Moore III, Scott Evans
3/26/2014 | 13-4302 | US v. Freddie Grant | William B. Traxler, Jr., Henry F. Floyd, Clyde H. Hamilton | Joshua Kendrick, Stacey Haynes
3/26/2014 | 13-4138 | US v. Deangelo McLaurin | William B. Traxler, Jr., Henry F. Floyd, Clyde H. Hamilton | Joshua Carpenter, Lawrence Hewitt , William Miller
3/20/2014 | 13-4371 | US v. Josephine Adams | Roger L. Gregory, Barbara Milano Keenan, Andre M. Davis | John Carr, Robert McWilliams Jr.
3/20/2014 | 13-4462 | US v. Dwayne Frazier | William B. Traxler Jr., Diana Gribbon Motz, Max O. Cogburn Jr. | Doug Keller, John Sippel Jr.
3/20/2014 | 13-4396 | US v. Jori Ferguson | Roger L. Gregory, Barbara Milano Keenan, Andre M. Davis | Nia Vidal, Michael Moore
3/20/2014 | 13-4136 | US v. Danilo Garcia | Roger L. Gregory, Barbara Milano Keenan, Andre M. Davis | Todd Brooks, Ayn Ducao
3/20/2014 | 13-4108 | US v. Charles Barefoot, Jr. | J. Harvie Wilkinson III, Robert B. King, Henry F. Floyd | Joseph Zeszotarski Jr., Seth Wood
3/20/2014 | 13-4039 | US v. Arthur Weiss | Paul V. Niemeyer, Albert Diaz, Clyde H. Hamilton | Charles White II, Todd Ellinwood
3/20/2014 | 13-4012 | US v. Christopher Perry | Allyson K. Duncan, G. Steven Agee, James A. Wynn, Jr. | Heather Martin, Sandra Wilkinson
3/20/2014 | 13-2018 | Valinda Streater v. Matthew Wilson | Allyson K. Duncan, G. Steven Agee, James A. Wynn, Jr. | Daniel Peterson, Mark Newbold, Fred DeVore III
3/20/2014 | 13-1702 | Nora Collins v. Pond Creek Mining Company | J. Harvie Wilkinson III, Robert B. King, Henry F. Floyd | Leonard Stayton , Kathy Snyder, Rita Roppolo
3/20/2014 | 13-1672 | US ex rel. Mike Ahumada v. NISH | Paul V. Niemeyer, Albert Diaz, Clyde H. Hamilton | Martin Restituyo, Robert Weaver Jr., Matthew Fitzgerald
3/20/2014 | 13-1626 | Leon Coursey v. University of MD Eastern Shore | William B. Traxler, Jr., Robert B. King, Max O. Cogburn Jr. | Robin Cockey, Jennifer Katz
3/20/2014 | 12-5045 | US v. Benjamin Carter | Paul V. Niemeyer, Albert Diaz, Clyde H. Hamilton | Lex Coleman, Philip Wright
3/20/2014 | 13-4401 | US v. Kenneth Wingle | Allyson K. Duncan, G. Steven Agee, James A. Wynn, Jr. | Peter Eliades, Katharine Adams
3/20/2014 | 13-4079 | US v. Gabriel Gutierrez | J. Harvie Wilkinson III, Diana Gribbon Motz, Henry F. Floyd | Joshua Carpenter, William Miller
3/19/2014 | 13-4212 | US v. Stanley Partman | Allyson K. Duncan, James A. Wynn, Jr., Albert Diaz | Casper Marcinak III, Robert Daley Jr.
3/19/2014 | 11-2416 | West Virginia CWP Fund v. Ardis Gump | Henry F. Floyd, Andre M. Davis, Max O. Cogburn | William Mattingly, Heath Long , Sean Bajkowski
3/19/2014 | 12-4910 | US v. Frank Marfo | Paul V. Niemeyer, G. Steven Agee, Clyde H. Hamilton | Kenneth McPherson, John Purcell Jr.
3/19/2014 | 12-5007 | US v. Adetokunbo Adepoju | Henry F. Floyd, Andre M. Davis, Max O. Cogburn | John Iweanoge II, Judson Mihok
3/19/2014 | 12-6941 | US v. Isabel Gonzalez | Diana Gribbon Motz, Robert B. King, Stephanie D. Thacker | Jeffrey Brandt, Seth Wood
3/19/2014 | 13-0284 | In re: Tadd Vassell | Paul V. Niemeyer, G. Steven Agee, Clyde H. Hamilton | Bryan Gowdy, Richard Cooke
3/19/2014 | 13-0288 | In re: Jeremiah Sloan | Paul V. Niemeyer, G. Steven Agee, Clyde H. Hamilton | Noell Tin, William Miller
3/19/2014 | 13-1460 | Shawn Massey v. J. Ojaniit | Diana Gribbon Motz, Robert B. King, Stephanie D. Thacker | James Coleman Jr., James Cooney III, Daniel Peterson
3/19/2014 | 13-1629 | Steven Lefemine v. Dan Wideman | Allyson K. Duncan, James A. Wynn, Jr., Albert Diaz | Steven Fitschen, Andrew Lindemann
3/19/2014 | 13-1868 | Kathleen Wood v. Crane Co | Allyson K. Duncan, James A. Wynn, Jr., Albert Diaz | Michael Ross, Jacqueline Badders
3/19/2014 | 13-6781 | Nathan Webb v. James Smith | Diana Gribbon Motz, Robert B. King, Stephanie D. Thacker | John Gunter, David Coats
3/19/2014 | 13-4220 | US v. Ildefonso Flores | Allyson K. Duncan, James A. Wynn, Jr., Albert Diaz | Andrew Banzhoff, April Christine
3/19/2014 | 13-4282 | US v. James Johnson | Diana Gribbon Motz, Robert B. King, Stephanie D. Thacker | Paul Beers, Katie Bagley
3/19/2014 | 13-6814 | Thomas Prousalis, Jr. v. Charles Moore | William B. Traxler Jr., J. Harvie Wilkinson III, Barbara Milano Keenan | Scott Martin, Jonathan Hambrick
3/19/2014 | 13-4457 | US v. Raymond Collins | William B. Traxler Jr., J. Harvie Wilkinson III, Barbara Milano Keenan | Joan Robin, Christopher Leibig, Michael Ben'Ary
3/19/2014 | 13-1839 | Joyce Barlow v. Colgate Palmolive Company | Henry F. Floyd, Andre M. Davis, Max O. Cogburn | William Adams, Jennifer Lilly
3/19/2014 | 13-4349 | US v. Stephen McFadden | William B. Traxler, Jr., J. Harvie Wilkinson III, Barbara Milano Keenan | J. Snook III, Jean Hudson
3/18/2014 | 13-1360 | Richard Tatum v. RJR Pension Investment Committ | J. Harvie Wilkinson III, Diana Gribbon Motz, Albert Diaz | Catha Worthman, Michael Hartman, Adam Charnes
3/18/2014 | 13-1937 | Suhail Al Shimari v. CACI Premier Technology, Inc. | Barbara Milano Keenan, Henry F. Floyd, Max O. Cogburn, Jr. | Baher Azmy, Robert LoBue, Joseph Koegel Jr.
3/18/2014 | 13-4100 | US v. Darrell Washington | William B. Traxler, Jr., Allyson K. Duncan, Andre M. Davis | Jonathan Milling, Jimmie Ewing
3/18/2014 | 13-4158 | US v. Saul Ramirez-Castillo | Roger L. Gregory, James A. Wynn, Jr., Stephanie D. Thacker | Cameron Blazer, Robert Bianchi
3/18/2014 | 13-4231 | US v. Eddie Louthian, Sr. | Paul V. Niemeyer, Robert B. King, G. Steven Agee | Michael Khouri, Janine Myatt
3/18/2014 | 13-4487 | US v. Jordan Laudermilt | Barbara Milano Keenan, Henry F. Floyd, Max O. Cogburn, Jr. | Stephen Herndon, Randolph Bernard
3/18/2014 | 13-6792 | US v. Randle Cooke | William B. Traxler, Jr., Allyson K. Duncan, Andre M. Davis | James Craven III, Matthew Fesak
3/18/2014 | 12-7675 | US v. Torrance Jones | Paul V. Niemeyer, Robert B. King, G. Steven Agee | Coreen Mao, Shailika Shah
3/18/2014 | 13-1931 | RailWorks Corporation v. Construction Program Group | Barbara Milano Keenan, Henry F. Floyd, Max O. Cogburn, Jr. | Annapoorni Sankaran, Zvi Guttman
3/18/2014 | 13-1849 | Paul Feldman v. Law Enforcement Associates | Roger L. Gregory, James A. Wynn, Jr., Stephanie D. Thacker | Adam Carter, Amy Jenkins
3/18/2014 | 13-1834 | Home Buyers Warranty Corp. v. Lois Hanna | J. Harvie Wilkinson III, Diana Gribbon Motz, Albert Diaz | Carlos Yguico, Christopher Brinkley
3/18/2014 | 13-1807 | Amanda Underwood v. West Virginia Dept. of Health | William B. Traxler, Jr., Allyson K. Duncan, Andre M. Davis | Nancy Dalby, Natalie Schaefer
3/18/2014 | 13-1382 | Chevron Corporation v. Aaron Page | Paul V. Niemeyer, Robert B. King, G. Steven Agee | James Tyrrell Jr., Thomas Dupree Jr.
3/18/2014 | 13-1708 | Best Medical International v. Eckert & Ziegler Nuclitec GmbH | Paul V. Niemeyer, Robert B. King, G. Steven Agee | James Brady, Carl Lonas
3/18/2014 | 13-1613 | Rolf Kamp v. Empire Fire and Marine Insuran | J. Harvie Wilkinson III, Diana Gribbon Motz, Albert Diaz | Ashley Creech, Theodore Rheney
3/18/2014 | 13-1583 | Sharon Bryant v. Carolyn Colvin | J. Harvie Wilkinson III, Diana Gribbon Motz, Albert Diaz | Marcia Anderson, David Mervis
3/18/2014 | 13-1579 | Denise Wilkins v. Vicki Montgomery | Roger L. Gregory, James A. Wynn, Jr., Stephanie D. Thacker | Gregory Lattimer, John Gilbody
3/18/2014 | 12-2503 | Sean Smith v. Peter Gilchrist, III | William B. Traxler, Jr., Allyson K. Duncan, Andre M. Davis | Matthew Arnold, Grady Balentine Jr., James Smith
3/18/2014 | 12-4724 | US v. Eric A. Fields | Roger L. Gregory, James A. Wynn, Jr., Stephanie D. Thacker | Mary Darrow, Joshua Rogers
1/30/2014 | 13-4049 | US v. Dawud Saafir | Diana Gribbon Motz, Andre M. Davis, Stephanie D. Thacker | John Dusenbury Jr., Michael DeFranco
1/30/2014 | 13-1765 | CoreTel Virginia, LLC v. Verizon Virginia, LLC | J. Harvie Wilkinson III, Paul V. Niemeyer, Allyson K. Duncan | Edward Tolchin, Scott Angstreich
1/30/2014 | 13-4063 | US v. John Stacks | Robert B. King, James A. Wynn, Jr., Henry F. Floyd | Joshua Carpenter, William Miller
1/30/2014 | 13-4285 | US v. Terry McVey | J. Harvie Wilkinson III, Paul V. Niemeyer, Allyson K. Duncan | Jonathan Byrne, Jennifer Rada
1/30/2014 | 13-4406 | US v. Khalil Blackman | J. Harvie Wilkinson III, Paul V. Niemeyer, Allyson K. Duncan | Marvin Miller, Gurney Grant II
1/30/2014 | 13-1031 | Joseph Antonio v. SSA Security, Inc. | Robert B. King, James A. Wynn, Jr., Henry F. Floyd | Ruthanne Deutsch, Gary Bryant
1/30/2014 | 12-7419 | US v. Thomas Blackledge | Roger L. Gregory, Dennis W. Shedd, Barbara Milano Keenan | Richard Croutharmel, Denise Walker
1/30/2014 | 12-4239 | US v. Jeffrey Edelen | Diana Gribbon Motz, Andre M. Davis, Stephanie D. Thacker | Gerald Ruter, Julie Johnson, Jerome Maiatico
1/30/2014 | 12-2561 | Armand Santoro v. Accenture Federal Services, LL | Roger L. Gregory, Dennis W. Shedd, Barbara Milano Keenan | Stephen Chertkof, Jonathan Cohn
1/30/2014 | 13-1106 | EEOC v. Baltimore County, Maryland | Roger L. Gregory, Dennis W. Shedd, Barbara Milano Keenan | James Nolan Jr., Paul Ramshaw
1/30/2014 | 12-5001 | US v. Romelus Martin | William B. Traxler, Jr., Albert Diaz, Liam O'Grady | Paresh Patel, Paul Nitze
1/30/2014 | 13-1588 | Cody Hearn v. Lancaster County | William B. Traxler, Jr., Albert Diaz, Liam O'Grady | William McKinnon, Andrew Lindemann
1/29/2014 | 13-4022 | US v. Evan Foreman | Diana Gribbon Motz, Robert B. King, Albert Diaz | Amy Copeland, Michael Morris , Benjamin Block
1/29/2014 | 13-4170 | US v. James Cobler | Allyson K. Duncan, Barbara Milano Keenan, James A. Wynn, Jr. | Christine Lee, Jean Hudson
1/29/2014 | 12-7905 | Donald Waters v. Harold Clarke | Paul V. Niemeyer, Dennis W. Shedd, Stephanie D. Thacker | Gregory Dolin, Matthew Dullaghan
1/29/2014 | 13-0005 | William Barnes v. Carlton Joyner | G. Steven Agee, Henry F. Floyd, Stephanie D. Thacker | Milton Widenhouse Jr., Jonathan Babb Sr.
1/29/2014 | 13-0006 | Jason Hurst v. Carlton Joyner | William B. Traxler, Jr., Paul V. Niemeyer, Dennis W. Shedd | Robert Hale Jr., Mary Hollis
1/29/2014 | 13-1318 | Cornerstone Title & Escrow, In v. Evanston Insurance Company | G. Steven Agee, G. Steven Agee, Henry F. Floyd, Henry F. Floyd, Stephanie D. Thacker, Stephanie | Stephan Brennan, Paul Farquharson
1/29/2014 | 13-1424 | Margarita Serna v. Eric Holder, Jr. | J. Harvie Wilkinson III, Roger L. Gregory, Andre M. Davis | Andrew Simpson, Antonia Konkoly
1/29/2014 | 13-1473 | Reya Boyer-Liberto v. Fontainebleau Corporation | William B. Traxler, Jr., Paul V. Niemeyer, Dennis W. Shedd | Robin Cockey, Harriet Cooperman
1/29/2014 | 13-1481 | Lori Freeman v. Dal-Tile Corporation | William B. Traxler, Jr., Paul V. Niemeyer, Dennis W. Shedd | Anne King, Kristine Sims
1/29/2014 | 13-1571 | Mulvey Construction, Inc. v. Bituminous Casualty Corp. | Allyson K. Duncan, Barbara Milano Keenan, James A. Wynn, Jr. | Stuart McMillan, Avrum Levicoff, Henry Willett III
1/29/2014 | 13-1889 | Dawn Flores v. Ethicon, Incorporated | Allyson K. Duncan, Barbara Milano Keenan, James A. Wynn, Jr. | Daniel Graham, Philip Combs
1/29/2014 | 13-4089 | US v. Demetrius Spence | G. Steven Agee, Henry F. Floyd, Stephanie D. Thacker | Michael Patrick, Shailika Shah
1/29/2014 | 12-4922 | US v. Larry Woods, Jr. | Allyson K. Duncan, Barbara Milano Keenan, James A. Wynn, Jr. | Matthew Joseph, Amy Ray
1/29/2014 | 13-4370 | US v. Ernest James McDowell, Jr. | Diana Gribbon Motz, Robert B. King, Albert Diaz | Robert Waters, Jennifer P. May-Parker
1/29/2014 | 12-1515 | The Chesapeake Bay Foundation, v. Weyerhaeuser Company | Diana Gribbon Motz, Robert B. King, Albert Diaz | Jack McKay, Tracy Steedman
1/29/2014 | 13-6186 | US v. Jeffrey Neuhauser | Diana Gribbon Motz, Robert B. King, Albert Diaz | Susan Hensler, Kristi O'Malley
1/29/2014 | 13-7152 | Deangelo Whiteside v. US | J. Harvie Wilkinson III, Roger L. Gregory, Andre M. Davis | Ann Hester, Amy Ray
1/29/2014 | 13-1644 | Jacqueline Rice v. Alpha Security, Incorporated | J. Harvie Wilkinson III, Roger L. Gregory, Andre M. Davis | Mary Kelly, Douglas Meister, Stephen Robinson
1/28/2014 | 13-1166 | 1899 Holdings, LLC v. 1899 Limited Liability Company | J. Harvie Wilkinson III, Barbara Milano Keenan, Albert Diaz | Meighan Burton, Paul Caiola
1/28/2014 | 10-0006 | US v. Alejandro Umana | Paul V. Niemeyer, Roger L. Gregory, G. Steven Agee | Vincent Brunkow, Adam Morris
1/28/2014 | 13-6043 | US v. Jose De La Luz Perez | William B. Traxler, Jr., Diana Gribbon Motz, Stephanie D. Thacker | Jenna Blue, Matthew Fesak
1/28/2014 | 12-2173 | James Owens v. Baltimore City State's Aty | William B. Traxler, Jr., Diana Gribbon Motz, James A. Wynn, Jr. | Charles Curlett Jr., Laura Abelson, Daniel Beck, Michele McDonald
1/28/2014 | 12-2515 | Maureen Hill v. Chuck Hagel | William B. Traxler, Jr., Diana Gribbon Motz, James A. Wynn, Jr. | Richard Seymour, David Moskowitz
1/28/2014 | 12-4947 | US v. Roger Camp | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | Jorgelina Araneda, Kristine Fritz
1/28/2014 | 13-4625 | In re: Under Seal | Paul V. Niemeyer, Roger L. Gregory, G. Steven Agee | Ian Samuel, Andrew Peterson
1/28/2014 | 12-5030 | US v. Erasto Gomez-Jimenez | Paul V. Niemeyer, Roger L. Gregory, G. Steven Agee | Paul Sun Jr., Joshua Rogers
1/28/2014 | 13-6661 | Timothy Austin v. Adrian Hoke | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | Erica Hashimoto, Steven Strasberg, Elbert Lin
1/28/2014 | 13-4238 | US v. Jose Henriquez | William B. Traxler, Jr., Diana Gribbon Motz, James A. Wynn, Jr. | Paresh Patel, Kelly Hayes
1/28/2014 | 13-1270 | In Re: H. Jason Gold | Allyson K. Duncan, Andre M. Davis, Henry F. Floyd | Brett Shumate ,N. Reid, Patrick Wallace
1/28/2014 | 13-1402 | Orlando Residence, Ltd. v. Kenneth Nelson | Allyson K. Duncan, Andre M. Davis, Henry F. Floyd | Gary Ahrens, Eugene Bulso Jr.
1/28/2014 | 13-1560 | Construction Supervision Svcs v. Branch Banking & Trust | Robert B. King, Dennis W. Shedd, James A. Wynn, Jr. | Nicholas Brown, William Wolf
1/28/2014 | 13-1594 | Steven Lincoln v. DOWCP | J. Harvie Wilkinson III, Barbara Milano Keenan, Albert Diaz | Gregory Camden, Lawrence Postol
1/28/2014 | 13-1687 | EEOC v. Propak Logistics, Incorporated | J. Harvie Wilkinson III, Barbara Milano Keenan, Albert Diaz | Susan Oxford, John Cole Sr.
1/28/2014 | 13-1813 | M.D. v. School Board City of Richmond | Allyson K. Duncan, Andre M. Davis, Henry F. Floyd | Peter Renn, Jim Guynn Jr.
1/28/2014 | 13-4059 | US v. Aaron Juarez-Gomez | Paul V. Niemeyer, Roger L. Gregory, G. Steven Agee | Joseph Gilbert, Joshua Rogers
1/28/2014 | 12-7155 | US v. Jatia Barrett | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | Michael Patrick, Robert Hamilton
12/12/2013 | 13-4037 | US v. Reggie Beckton | Diana Gribbon Motz, Barbara Milano Keenan, Stephanie D. Thacker | Richard Croutharmel, Kristine Fritz
12/12/2013 | 12-4603 | US v. Marcel Aparicio-Soria | Traxler, Wilkinson,Niemeyer,Motz ,King,Gregory,Shedd,Duncan,Agee,Keenan,Wynn,Diaz,Floyd,Thacker | Sapna Mirchandani, Paul Nitze
12/12/2013 | 12-1259 | Arthur Drager v. PLIVA USA | Dennis W. Shedd, Allyson K. Duncan, Andre M. Davis | Louis Bograd, Michael Shumsky
12/12/2013 | 12-1866 | Westmoreland Coal Company, Inc v. Edward Stidham | Paul V. Niemeyer, G. Steven Agee, James A. Wynn, Jr. | Thomas Hancock, Ryan Gilligan, Jeffrey Goldberg
12/12/2013 | 12-2396 | T-Mobile Northeast LLC v. The Loudoun County Board | Paul V. Niemeyer, G. Steven Agee, James A. Wynn, Jr. | Thomas Stoner, Thomas Thompson
12/12/2013 | 12-2553 | Trans Energy, Inc. v. EQT Production Company | J. Harvie Wilkinson III, Roger L. Gregory, John A. Gibney, Jr. | W. Lawrence IV, James Ho, Stuart McMillan
12/12/2013 | 13-4118 | US v. Tashell Waller | Dennis W. Shedd, Allyson K. Duncan, Andre M. Davis | Patrick Bryant, Erik Siebert
12/12/2013 | 12-4434 | US v. Megan Mosteller | Diana Gribbon Motz, Barbara Milano Keenan, Stephanie D. Thacker | Bradley Kirkland, William Day II
12/12/2013 | 13-4132 | US v. Dwane Washington | William B. Traxler, Jr., Albert Diaz, Henry F. Floyd | James Donnelly, Brian Hood
12/12/2013 | 12-4896 | US v. Brandon Ingram | William B. Traxler, Jr., Albert Diaz, Henry F. Floyd | Walter Paramore III, Joshua Rogers
12/12/2013 | 12-4937 | US v. Donavon Crawford | Diana Gribbon Motz, Barbara Milano Keenan, Stephanie D. Thacker | John Bryson, Clifton Barrett
12/12/2013 | 12-4962 | US v. Carlos Ruiz | Dennis W. Shedd, Allyson K. Duncan, Andre M. Davis | Anthony Martin, Sujit Raman
12/12/2013 | 12-5006 | US v. Juan Calderon | J. Harvie Wilkinson III, Robert B. King, Roger L. Gregory | Russell Mace III, Andrew Moorman
12/12/2013 | 13-1194 | Millennium Inorganic Chemicals v. National Union Fire Insurance | Paul V. Niemeyer, G. Steven Agee, James A. Wynn Jr. | Charles Cole, Joseph Beavers
12/12/2013 | 13-4083 | US v. Youssef Abdelbary | William B. Traxler, Jr., Albert Diaz, Henry F. Floyd | Paul Beers, Joseph Mott
12/12/2013 | 12-2572 | Core Communications, Inc. v. Verizon Maryland LLC | J. Harvie Wilkinson III, Robert B. King, Roger L. Gregory | Ralph Gleaton II, Scott Angstreich
12/11/2013 | 13-1788 | Audrey Kenney v. Independent Order of Foresters | G. Steven Agee, Barbara Milano Keenan, Henry F. Floyd | Don Parker, Robert Massie
12/11/2013 | 13-4067 | US v. William Bridges | J. Harvie Wilkinson III, Albert Diaz, Stephanie D. Thacker | Brian Beck, Jennifer Bockhorst
12/11/2013 | 13-1691 | Montgomery County, Maryland v. Federal National Mortgage Asso | William B. Traxler, Jr., Paul V. Niemeyer, Allyson K. Duncan | Don Springmeyer, Michael Johnson, Patrick Urda
12/11/2013 | 13-1374 | Dickenson-Russell Coal Company v. Secretary of Labor | William B. Traxler, Jr., Paul V. Niemeyer, Allyson K. Duncan | Patrick Dennison, Samuel Lord
12/11/2013 | 13-1076 | John Corr v. Metropolitan Washington | William B. Traxler, Jr., Paul V. Niemeyer, Allyson K. Duncan | Robert Cynkar, Stuart Raphael, Jeffrey Clair
12/11/2013 | 12-4545 | US v. Charles Galloway | William B. Traxler, Jr., Paul V. Niemeyer, Allyson K. Duncan | Megan Coleman, Sujit Raman
12/11/2013 | 13-6355 | Gary Wall v. James Wade | Roger L. Gregory, Andre M. Davis, James A. Wynn, Jr. | Elizabeth Turner, Earle Getchell Jr.
12/11/2013 | 13-4356 | US v. Brian Bishop | J. Harvie Wilkinson III, Albert Diaz, Stephanie D. Thacker | Joseph Hannon Jr., Richard Cooke
12/11/2013 | 13-1143 | Carnell Construction Corp. v. Danville RHA | G. Steven Agee, Barbara Milano Keenan, Henry F. Floyd | Rhonda Harmon, John Eure, Joseph Pope
12/11/2013 | 13-4093 | US v. Philip Sebolt | Roger L. Gregory, Andre M. Davis, James A. Wynn, Jr. | Frances Pratt, Thomas Johnstone IV
12/11/2013 | 12-2400 | US v. Byron Antone | Roger L. Gregory, Andre M. Davis, James A. Wynn, Jr. | Eric Brignac, Michael Bredenberg
12/11/2013 | 13-4066 | US v. Harvey Cox | J. Harvie Wilkinson III, Albert Diaz, Stephanie D. Thacker | John Haley, Peter Phillips
12/11/2013 | 13-1570 | Tom Price v. City of Fayetteville | J. Harvie Wilkinson III, Barbara Milano Keenan, Stephanie D. Thacker | Nathan Kellum, Karen McDonald, Andrew Erteschik
12/11/2013 | 12-4487 | US v. Janson Strayhorn | Roger L. Gregory, Andre M. Davis, James A. Wynn, Jr. | James Craven III, Andrew Cochran
12/11/2013 | 12-4462 | US v. Samuel Ocasio | Diana Gribbon Motz, Robert B. King, Dennis W. Shedd | Matthew Owen, Kathleen O'Connel Gavin
12/11/2013 | 12-2489 | Silicon Knights, Inc v. Epic Games, Inc | G. Steven Agee, Barbara Milano Keenan, Henry F. Floyd | Christopher Holland, Michael Shebelskie
12/11/2013 | 12-2465 | Robert Anderson v. Architectural Glass Constr | Diana Gribbon Motz, Robert B. King, Dennis W. Shedd | Richard Simons, William Epps III
12/11/2013 | 13-4252 | US v. Awni Shauaib Zayyad | G. Steven Agee, Albert Diaz, Henry F. Floyd | Joshua Carpenter, David Lieberman
12/10/2013 | 12-7954 | Henh Chu Ngo v. Gregory Holloway | William B. Traxler, Jr., J. Harvie Wilkinson III, Andre M. Davis | Jonathan Sheldon, Craig Stallard
12/10/2013 | 13-1259 | Jordan Eskridge v. Pacific Cycle, Inc. | William B. Traxler, Jr., J. Harvie Wilkinson III, Andre M. Davis | Christopher Brinkley, Tanya Hunt Handley
12/10/2013 | 12-6756 | US v. Ralph Jackson | William B. Traxler, Jr., J. Harvie Wilkinson III, Andre M. Davis | Robert Littlehale III, Anthony Giorno
12/10/2013 | 12-2273 | Clifton Valentine v. Sugar Rock, Inc. | Robert B. King, Roger L. Gregory, Henry F. Floyd | James Huggins, W. Lawrence IV
12/10/2013 | 12-2431 | US ex rel. Barry Rostholder v. Omnicare, Incorporated | Paul V. Niemeyer, Dennis W. Shedd, Barbara Milano Keenan | Gerald Robinson, James Martin
12/10/2013 | 12-4636 | US v. Robert Freeman | Allyson K. Duncan, James A. Wynn, Jr., Stephanie D. Thacker | Nancy Forster, Thomas Windom
12/10/2013 | 12-7472 | US v. Thomas Heyer | Diana Gribbon Motz, G. Steven Agee, Albert Diaz | Eric Brignac, Denise Walker
12/10/2013 | 13-1215 | Marie M. McCray v. Maryland Dept of Trans | Robert B. King, Roger L. Gregory, Henry F. Floyd | John Morris Jr., Jennifer Katz
12/10/2013 | 12-1881 | North Carolina Utilities Comm v. FERC | Allyson K. Duncan, James A. Wynn Jr., Stephanie D. Thacker | Kimberly Duffley, Lona Perry
12/10/2013 | 13-1369 | VCA Cenvet Incorporated v. Chadwell Animal Hospital LLC | Paul V. Niemeyer, Dennis W. Shedd, Barbara Milano Keenan | Brian Casey, Meighan Burton
12/10/2013 | 13-1438 | Jamie Meyers v. Michael Lamer | Robert B. King, Roger L. Gregory, Henry F. Floyd | Paul Bekman, Brian Goodman, Emily Malarkey
12/10/2013 | 13-1445 | Joe Pliler v. Richard Stearns | Allyson K. Duncan, James A. Wynn, Jr., Stephanie D. Thacker | Robert Roland IV, Christopher Kirk, Isaac Johnston
12/10/2013 | 13-1517 | Robert Graham v. National Union Fire Insurance | Robert B. King, Roger L. Gregory, Henry F. Floyd | Michael Carey, Don Parker
12/10/2013 | 13-1645 | Carl Summers v. Altarum Institute, Corporation | Diana Gribbon Motz, G. Steven Agee, Albert Diaz | David Scher, Paul Coughenour
12/10/2013 | 13-6594 | US v. Matthew Mason | William B. Traxler, Jr., J. Harvie Wilkinson III, Andre M. Davis | Brendan Leary, Erin Reisenweber
12/10/2013 | 13-1084 | Gustavo Urbina v. Eric Holder, Jr. | Diana Gribbon Motz, G. Steven Agee, Albert Diaz | Philip Eichorn, Jennifer Williams
11/6/2013 | 12-2389 | Daniel Newbanks v. Cellular Sales of Knoxville | Roger L. Gregory, Andre M. Davis, Stephanie D. Thacker | Charles Carbo III, Robert Dodson
11/6/2013 | 12-2256 | Liberty Mutual Fire Insurance v. JT Walker Industries, Inc. | Roger L. Gregory, Andre M. Davis, Stephanie D. Thacker | Richard Lumpkin, Charles Brown
11/6/2013 | 12-2482 | Roger Hoschar v. Appalachian Power Company | Roger L. Gregory, Andre M. Davis, Stephanie D. Thacker | Alexander McLaughlin, Daniel Michelmore
10/31/2013 | 12-2340 | FTC v. Kristy Ross | Andre M. Davis, Henry F. Floyd, Clyde H. Hamilton | Robert Greenspoon, Theodore (Jack) Metzler
10/31/2013 | 12-4175 | US v. James Harris | J. Harvie Wilkinson III, Allyson K. Duncan, Albert Diaz | Steven Levin, Michael Hanlon
10/31/2013 | 12-4191 | US v. Timothy Wilson | J. Harvie Wilkinson III, Allyson K. Duncan, Albert Diaz | Susan Hensler, Michael Montemarano , Joshua Kaul
10/31/2013 | 12-4374 | US v. Leconie Williams, IV | Paul V. Niemeyer, James A. Wynn Jr., Louise W. Flanagan | Mary Davis, Jonathan Ophardt
10/31/2013 | 12-4416 | US v. Gregory Graves | Diana Gribbon Motz, G. Steven Agee, Joseph F. Anderson Jr. | Meghan Skelton, Steven Swaney
10/31/2013 | 12-4612 | US v. Tremayne Bugg | William B. Traxler Jr., Robert B. King, Stephanie D. Thacker | Joel Hoppe, Kartic Padmanabhan
10/31/2013 | 12-4743 | US v. Marcus Gibbs | Andre M. Davis, Henry F. Floyd, Clyde H. Hamilton | J. Condon Jr., Nathan Williams
10/31/2013 | 12-4879 | US v. Herbert Green | Roger L. Gregory, Dennis W. Shedd, Barbara Milano Keenan | Randy Cargill, Thomas Booth
10/31/2013 | 12-4957 | US v. Mohammed Keita | Paul V. Niemeyer, James A. Wynn, Jr., Louise W. Flanagan | Marc Hall, Sujit Raman
10/31/2013 | 12-2543 | Frederick Bouchat v. Baltimore Ravens Limited | J. Harvie Wilkinson III, Allyson K. Duncan, Albert Diaz | Howard Schulman, Robert Raskopf
10/31/2013 | 12-7298 | US v. Rolando Stockton | William B. Traxler Jr., Robert B. King, Stephanie D. Thacker | Michael Lawlor, James Warwick
10/31/2013 | 13-1064 | Christine Seney v. Rent-a-Center, Incorporated | Diana Gribbon Motz, G. Steven Agee, Joseph F. Anderson Jr. | Daniel Whitney Sr., James Mehigan
10/31/2013 | 13-1129 | Debra McMurray v. US | William B. Traxler Jr., Robert B. King, Stephanie D. Thacker | Mark Sternlicht, Joshua Royster
10/31/2013 | 12-2424 | Julio Martinez v. Eric Holder, Jr. | Paul V. Niemeyer, James A. Wynn, Jr., Louise W. Flanagan | Maureen Sweeney, Benjamin Casper, Oluremi da Rocha-Afodu
10/31/2013 | 13-1134 | Sandlands C&D LLC v. Horry, County of | J. Harvie Wilkinson III, Allyson K. Duncan, Albert Diaz | Vincent Sheheen, Michael Battle
10/31/2013 | 13-1258 | Occupy Columbia v. Nikki Haley | William B. Traxler Jr., Robert B. King, Stephanie D. Thacker | Kevin Hall, Andrew Radeker
10/31/2013 | 12-4949 | US v. Paul Boccone | Paul V. Niemeyer, James A. Wynn, Jr., Louise W. Flanagan | Emma Burnham, John Iweanoge II, Michael Ben'Ary
10/31/2013 | 12-2526 | Ronald Bradley v. Christopher Fina | Roger L. Gregory, Dennis W. Shedd, Barbara Milano Keenan | Kevin Funk, Richard Hall
10/31/2013 | 12-2309 | Maritza Reyes v. Harry Lee Jeffcoat | Roger L. Gregory, Dennis W. Shedd, Barbara Milano Keenan | Rebecca Fulmer, Reid Sherard
10/31/2013 | 12-2209 | Company Doe v. Public Citizen | Andre M. Davis, Henry F. Floyd, Clyde H. Hamilton | Scott Michelman, Baruch Fellner
10/31/2013 | 11-4618 | US v. Chinua Shepperson | Diana Gribbon Motz, G. Steven Agee, Joseph F. Anderson Jr. | Ray Shepard, Sujit Raman
10/30/2013 | 13-1030 | American Civil Liberties Union v. Anthony Tata | William B. Traxler Jr., James A. Wynn, Jr., George L. Russell III | Kathryne Hathcock, Christopher Brook
10/30/2013 | 12-2126 | Swatch AG (Swatch SA) v. Beehive Wholesale, LLC | Paul V. Niemeyer, Robert B. King, Allyson K. Duncan | Jeffrey Lindenbaum, William Utermohlen
10/30/2013 | 12-2303 | James Durham v. Robert Jones | Diana Gribbon Motz, Roger L. Gregory, Andre M. Davis | Julia Bernhardt, Howard Hoffman
10/30/2013 | 12-2415 | Perini/Tompkins Joint Venture v. ACE American Insurance Company | Dennis W. Shedd, Stephanie D. Thacker, Clyde H. Hamilton | Gregory Podolak, Joseph Powers
10/30/2013 | 12-2481 | Eileen McAfee v. Christine Boczar | Paul V. Niemeyer, Robert B. King, Allyson K. Duncan | Henry Keuling-Stout, William Hurd
10/30/2013 | 12-2575 | Baltimore City Substance Abuse v. Mayor and City Council of Balt | J. Harvie Wilkinson III, G. Steven Agee, Barbara Milano Keenan | William Anderson, Matthew Nayden
10/30/2013 | 12-4484 | US v. Kurt Steffen | J. Harvie Wilkinson III, G. Steven Agee, Barbara Milano Keenan | Kimberly Albro, Robert Bianchi
10/30/2013 | 12-4625 | US v. Henry Stephens | Dennis W. Shedd, Stephanie D. Thacker, Clyde H. Hamilton | Christopher Cowan, Albert Copperthite
10/30/2013 | 12-4935 | US v. Carlos Perez-Perez | Diana Gribbon Motz, Roger L. Gregory, Andre M. Davis | Bettina Roberts, Joshua Rogers
10/30/2013 | 12-4940 | US v. James Collins, Jr. | Diana Gribbon Motz, Roger L. Gregory, Andre M. Davis | Clarence Wise, Nathan Williams
10/30/2013 | 12-2047 | Marqus Stevenson v. City of Seat Pleasant, MD | Albert Diaz, Henry F. Floyd, Joseph F. Anderson Jr. | Gregory Lattimer, Shelley Johnson, Victoria Shearer
10/30/2013 | 12-7653 | US v. Vernon Wood | Dennis W. Shedd, Stephanie D. Thacker, Clyde H. Hamilton | James Todd Jr., Michael James
10/30/2013 | 12-2496 | Robert Yates v. Municipal Mortgage & Equity | Albert Diaz, Henry F. Floyd, Joseph F. Anderson, Jr. | David Brower, William Jay, Mark Holland, Jason Mendro
10/30/2013 | 13-1151 | Dana Clark v. Absolute Collection Service | Albert Diaz, Henry F. Floyd, Joseph F. Anderson, Jr. | Deepak Gupta, Sean Partrick
10/30/2013 | 13-1430 | Alan Metzgar v. KBR, Incorporated | Albert Diaz, Henry F. Floyd, Joseph F. Anderson, Jr. | Susan Burke, Robert Matthews
10/30/2013 | 13-4171 | US v. Reginald Dargan, Jr. | J. Harvie Wilkinson III, G. Steven Agee, Barbara Milano Keenan | Brian Stekloff, Benjamin Block
10/30/2013 | 13-4198 | Kim Kinder v. Michael White | William B. Traxler Jr., James A. Wynn, Jr., George L. Russell III | Jonathan Byrne, James Cagle
10/30/2013 | 13-6228 | US v. Darnell Black | Paul V. Niemeyer, Robert B. King, Allyson K. Duncan | G. DuBois, Yvonne Watford-McKinney
10/30/2013 | 13-6326 | US v. Richard Savage | J. Harvie Wilkinson III, G. Steven Agee, Barbara Milano Keenan | Jeffrey Gillette, Michael Bredenberg
10/30/2013 | 12-7121 | US v. Erik Dehlinger | Diana Gribbon Motz, Roger L. Gregory, Andre M. Davis | Michael Minns, Kevin Lombardi
10/29/2013 | 13-1192 | Tumaini Temu v. Eric Holder, Jr. | Robert B. King, Roger L. Gregory, G. Steven Agee | Katie Bukrinsky, Woei-Tyng Shieh , Thomas Tynan
10/29/2013 | 13-1058 | Vijay Taneja v. First Tennessee Bank NA | Barbara Milano Keenan, James A. Wynn, Jr., Stephanie D. Thacker | Kenneth Oestreicher, Clarence Wilbon
10/29/2013 | 12-4639 | US v. Steven Robinson | Paul V. Niemeyer, Diana Gribbon Motz, Albert Diaz | Seth Neyhart, Joshua Rogers
10/29/2013 | 12-1994 | Jeffrey Gray v. Frederick County, Maryland | Barbara Milano Keenan, James A. Wynn Jr., Stephanie D. Thacker | Gregory Lattimer, Sandra Lee
10/29/2013 | 12-2574 | NTEU v. FLRA | William B. Traxler Jr., J. Harvie Wilkinson III, Henry F. Floyd | Peyton Lawrimore, Zachary Henige
10/29/2013 | 12-2387 | Mary Fox v. Elk Run Coal Company, Inc. | William B. Traxler Jr., J. Harvie Wilkinson III, Henry F. Floyd | Allan Karlin, Alvin Emch
10/29/2013 | 12-4469 | US v. Keith Simmons | Paul V. Niemeyer, Diana Gribbon Motz, John A Gibney, Jr | Joshua Carpenter, William Miller
10/29/2013 | 12-4912 | US v. Charlie Bryant | Barbara Milano Keenan, James A. Wynn, Jr., Stephanie D. Thacker | Cindy Popkin-Bradley, William Miller
10/29/2013 | 13-1368 | Al Pisano v. Kim Strach | Paul V. Niemeyer, Diana Gribbon Motz, Albert Diaz | Robert Bastress Jr., Susannah Holloway
10/29/2013 | 13-6358 | Maceo Spates v. Harold Clarke | William B. Traxler Jr., J. Harvie Wilkinson III, Henry F. Floyd | Matthew Dullaghan, Neal Walters
10/29/2013 | 13-4267 | US v. Under Seal | Robert B. King, Roger L. Gregory, G. Steven Agee | Caroline Rule, Elissa Hart-Mahan
10/29/2013 | 13-1492 | Clear Sky Car Wash LLC v. City of Chesapeake, Virginia | Paul V. Niemeyer, Diana Gribbon Motz, Albert Diaz | Edward Grass, Kent Porter, Thomas Salb
10/29/2013 | 13-1406 | Cobra Natural Resources, LLC v. Federal Mine Safety & Health | Robert B. King, Roger L. Gregory, G. Steven Agee | William Robinson, Nancy Steffan
10/29/2013 | 12-2547 | Aaron Ross v. Wayne Early | Barbara Milano Keenan, James A. Wynn, Jr., Stephanie D. Thacker | Sean Day, Steven Potter, Barron Stroud Jr.
10/29/2013 | 12-2490 | Snider International Corp. v. Town of Forest Heights, MD | Robert B. King, Roger L. Gregory, G. Steven Agee | James Liskow, Kevin Karpinski
10/29/2013 | 12-2477 | Vicky Bennett v. CSX Transportation, Incorporat | William B. Traxler Jr., J. Harvie Wilkinson III, Henry F. Floyd | Evan Tager, William McLeod Jr.
9/20/2013 | 12-2360 | Beth Cosey v. The Prudential Insurance Co. | Andre M. Davis, Barbara Milano Keenan, Henry F. Floyd | Norris Adams II, Patrick DiCarlo
9/20/2013 | 12-2287 | US ex rel. Steven May v. Purdue Pharma L.P. | William B. Traxler, Jr., Albert Diaz, Gina M. Groh | Mark Hurt, Henry Whitaker, Howard Shapiro
9/20/2013 | 12-2316 | Gurpinder Othi v. Eric Holder, Jr. | Paul V. Niemeyer, G. Steven Agee, Clyde H. Hamilton | Jonathan Ai, Walter Bocchini
9/20/2013 | 11-5043 | US v. Jenerette Dixon | Paul V. Niemeyer, G. Steven Agee, Clyde H. Hamilton | Gerald Ruter, James Warwick
9/20/2013 | 12-4167 | US v. Lamondes Williams | Roger L. Gregory, Allyson K. Duncan, Samuel G. Wilson | Judith Sakyi, John Iweanoge II, Barbara Sale
9/20/2013 | 12-4664 | US v. Randall McGee | Andre M. Davis, Barbara Milano Keenan, Henry F. Floyd | Jonathan Byrne, Monica Coleman
9/20/2013 | 12-4319 | US v. John Franklin | Andre M. Davis, Barbara Milano Keenan, Henry F. Floyd | Jenifer Wicks, John Sippel Jr.
9/20/2013 | 12-4358 | US v. Richard Jaensch | Roger L. Gregory, Allyson K. Duncan, Samuel G. Wilson | Alan Cilman, Marvin Miller, Gregory Davis
9/20/2013 | 12-4486 | US v. Jamaal Antonio Robertson | Roger L. Gregory, Allyson K. Duncan, Samuel G. Wilson | Ronald Cohen, Michael DeFranco
9/20/2013 | 12-4828 | US v. Carlos Bautista-Villanueva | Paul V. Niemeyer, G. Steven Agee, Clyde H. Hamilton | Joanna Silver, Rod Rosenstein
9/20/2013 | 12-4509 | US v. Rodney Lucas | William B. Traxler, Jr., Albert Diaz, Gina M. Groh | Stephen Gordon, Joshua Rogers
9/20/2013 | 12-4642 | US v. Lucio Deleon-Ramirez | Diana Gribbon Motz, Dennis W. Shedd, Stephanie D. Thacker | Nicholas Xenakis, Michael Moore
9/20/2013 | 12-4426 | US v. Armond Dowdell | William B. Traxler, Jr., Albert Diaz, Gina M. Groh | Gerald Ruter, Benjamin Block
9/20/2013 | 12-4856 | US v. Austin Webb, Jr. | Andre M. Davis, Barbara Milano Keenan, Henry F. Floyd | Christine Lee, Jean Hudson
9/20/2013 | 13-1418 | Kellie Ballard v. Bank of America, NA | Diana Gribbon Motz, Dennis W. Shedd, Stephanie D. Thacker | Roger Simmons, E. Steren
9/20/2013 | 13-1071 | George Cooper, Sr. v. James Sheehan | J. Harvie Wilkinson III, Robert B. King, James A. Wynn Jr. | Christopher Geis, Laura Conner, Robert Tatum
9/20/2013 | 12-5043 | US v. Decarlos George | Paul V. Niemeyer, G. Steven Agee, Clyde H. Hamilton | James Martin, Yvonne Watford-McKinney
9/20/2013 | 12-4901 | US v. William McManus | Roger L. Gregory, Allyson K. Duncan, Samuel G. Wilson | Eugene Lester III, Anand Ramaswamy
9/20/2013 | 12-4853 | US v. Demeco Richardson | Diana Gribbon Motz, Dennis W. Shedd, Stephanie D. Thacker | Larry Economos, Yvonne Watford-McKinney
9/20/2013 | 12-4680 | US v. Rodney Burrell | Diana Gribbon Motz, Dennis W. Shedd, Stephanie D. Thacker | Mitchell Styers, Joshua Rogers
9/20/2013 | 12-5039 | US v. Faisal Hashime | J. Harvie Wilkinson III, Robert B. King, James A. Wynn Jr. | Jonathan Shapiro, Maureen Cain, Peter Greenspun
9/19/2013 | 12-2513 | US ex rel. Jon H. Oberg v. Pennsylvania Higher Education | William B. Traxler, Jr., Diana Gribbon Motz, Barbara Milano Keenan | Bert Rein ,Daniel Huyett, John West, N. Connally III
9/19/2013 | 12-4775 | US v. Norman Kerr | G. Steven Agee, Andre M. Davis, Albert Diaz | George Crump III, Ripley Rand
9/19/2013 | 12-4061 | US v. Mohammad Hassan | J. Harvie Wilkinson III, Robert B. King, Samuel G. Wilson | Robert Boyle, Robert Boyce, John Fischer, Jason Kellhofer
9/19/2013 | 12-2498 | Philip Morris USA, Incorporate v. Thomas Vilsack | Allyson K. Duncan, Stephanie D. Thacker, Gina M. Groh | Lauren Goldman, Sydney Foster, Daniel Jarcho
9/19/2013 | 12-4630 | US v. Suado Ali | Paul V. Niemeyer, Roger L. Gregory, Henry F. Floyd | Joseph McCarthy , Thomas Walsh, William Cummings, Michael Frank
9/19/2013 | 12-7722 | James Denny v. Mark Tucker | Allyson K. Duncan, Stephanie D. Thacker, Gina M. Groh | James Stuckey Jr., Gregg Meyers
9/19/2013 | 12-5035 | US v. Jimmy Hunter | Dennis W. Shedd, James A. Wynn Jr., Clyde H. Hamilton | Curtis Holmes, Joshua Rogers
9/19/2013 | 12-2279 | Ai Chen v. Eric Holder, Jr. | William B. Traxler, Jr., Diana Gribbon Motz, Barbara Milano Keenan | Alexa Torres, Walter Bocchini
9/19/2013 | 12-2272 | Colon Health Centers v. Bill Hazel | J. Harvie Wilkinson III, Robert B. King, Samuel G. Wilson | Robert McNamara, Earle Getchell Jr.
9/19/2013 | 12-2241 | Projects Management Company v. DynCorp International LLC | G. Steven Agee, Andre M. Davis, Albert Diaz | Thomas Kenworthy, Joseph Koegel Jr.
9/19/2013 | 12-2001 | Medicine Shoppe International, v. Mohammed Siddiqui | Allyson K. Duncan, Stephanie D. Thacker, Gina M. Groh | Stephen O'Brien, David Silbiger
9/19/2013 | 12-2232 | Prospect Capital Corporation v. Adkisson Sherbert & Associates | G. Steven Agee, Andre M. Davis, Albert Diaz | Karl Huth IV, Frederick Sharpless
9/19/2013 | 12-2170 | Noah Nathan v. Takeda Pharmaceuticals America | J. Harvie Wilkinson III, Robert B. King, Samuel G. Wilson | James Bell, Dana Rust
9/19/2013 | 12-1887 | Hui Pan v. Eric Holder, Jr. | William B. Traxler, Jr., Diana Gribbon Motz, Barbara Milano Keenan | Joshua Berman, Stephen Elliott
9/19/2013 | 12-2085 | Devin Hamden v. Total Car Franchising Corp | Paul V. Niemeyer, Roger L. Gregory, Henry F. Floyd | Frank Friedman, Robert Dean II
9/19/2013 | 12-2100 | Jeffery Guiton v. Carolyn W. Colvin | G. Steven Agee, Andre M. Davis, Albert Diaz | B. Phillips, Jason Valencia
9/19/2013 | 12-2127 | Garon Reeves v. IRS | Dennis W. Shedd, James A. Wynn Jr., Clyde H. Hamilton | William Brewer Jr., Angus McKellar
9/19/2013 | 12-2161 | US v. 515 Granby, LLC | Allyson K. Duncan, Stephanie D. Thacker, Gina M. Groh | William Wilkins, Joan Pepin
9/19/2013 | 12-2212 | Maria Durden v. US | Paul V. Niemeyer, Roger L. Gregory, Henry F. Floyd | Nathan Harrill, Joshua Royster
9/19/2013 | 12-1617 | Tammy Fontenot v. Taser International, Inc. | William B. Traxler, Jr., Diana Gribbon Motz, Barbara Milano Keenan | Pamela Petersen, John Burton
9/18/2013 | 12-2010 | Zee Company, Inc. v. Williams Mullen | Paul V. Niemeyer, Robert B. King, G. Steven Agee | Mark Dombroff, William Bayliss
9/18/2013 | 12-4531 | US v. Kendrick Crawford | J. Harvie Wilkinson III, Diana Gribbon Motz, Henry F. Floyd | G. DuBois, Yvonne Watford-McKinney
9/18/2013 | 12-4179 | US v. Shenika Graves | Roger L. Gregory, Stephanie D. Thacker, Clyde H. Hamilton | Gary Ticknor, Howard Margulies, Joshua Kaul
9/18/2013 | 12-2458 | Anna Agolli v. Office Depot, Inc. | Paul V. Niemeyer, Robert B. King, G. Steven Agee | Matthew Fyock, Kevin Kraham
9/18/2013 | 12-1167 | Lakshmi Injeti v. United States Citizenship | Andre M. Davis, James A. Wynn Jr., Albert Diaz | Jeffrey O'Toole, Erez Reuveni
9/18/2013 | 12-1414 | Jerrell Johnson v. Stephen Rankin | J. Harvie Wilkinson III, Diana Gribbon Motz, Henry F. Floyd | Fletcher Alford, Richard Cromwell
9/18/2013 | 12-1729 | Anwar Haddam v. Eric Holder, Jr. | Roger L. Gregory, Stephanie D. Thacker, Clyde H. Hamilton | Rene Kathawala, Christopher Fuller
9/18/2013 | 12-1943 | Calvin Barton v. House of Raeford Farms, Inc. | Paul V. Niemeyer, Robert B. King, G. Steven Agee | James Stine, Nancy Bloodgood
9/18/2013 | 12-8148 | Jamey Wilkins v. Officer Gaddy | J. Harvie Wilkinson III, Diana Gribbon Motz, Henry F. Floyd | David Strauss, Kimberly Grande, Jonathan Levy
9/18/2013 | 12-2269 | Gaines Motor Lines, Inc. v. Klaussner Furniture Industries | Dennis W. Shedd, Allyson K. Duncan, Barbara Milano Keenan | Robert Moseley Jr., James Dean
9/18/2013 | 12-2175 | Kiran Dewan, CPA, P.A. v. Arun Walia | Andre M. Davis, James A. Wynn Jr., Albert Diaz | Paul Schleifman, Mark Chalpin
9/18/2013 | 12-2452 | First Financial Insurance Comp v. Tonya Brumbaugh | Dennis W. Shedd, Allyson K. Duncan, Barbara Milano Keenan | Mark Barrow, William McLeod Jr.
9/18/2013 | 12-2259 | Baltazar Garcia v. Eric Holder, Jr. | J. Harvie Wilkinson III, Diana Gribbon Motz, Henry F. Floyd | Jeremy McKinney, Brendan Hogan
9/18/2013 | 12-2157 | Gerardo Ayala v. J. Wolfe, II | Andre M. Davis, James A. Wynn Jr., Albert Diaz | Eugene Lester III, Jack Strauch
9/18/2013 | 12-2302 | Qing Lin v. Eric Holder, Jr. | Roger L. Gregory, Stephanie D. Thacker, Clyde H. Hamilton | Joshua Bardavid, Jonathan Robbins
9/18/2013 | 12-1738 | Peng Ye v. Eric Holder, Jr. | Roger L. Gregory, Stephanie D. Thacker, Clyde H. Hamilton | Scott Bratton, Jonathan Robbins
9/17/2013 | 12-0342 | Quicken Loans Incorporated v. Phillip Alig | Paul V. Niemeyer, James A. Wynn Jr., Henry F. Floyd | Meir Feder, John Barrett
9/17/2013 | 12-2366 | Adrian Muldrow v. Schmidt Baking Company, Inc. | Diana Gribbon Motz, Albert Diaz, John A. Gibney, Jr. | Jon Gordon, Kathleen Pontone
9/17/2013 | 12-4760 | US v. Fabian Montes-Flores | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | Kimberly Albro, Robert Bianchi
9/17/2013 | 13-1024 | Rickey Carroll v. John Logan | Paul V. Niemeyer, James A. Wynn, Jr., Henry F. Floyd | Cortney Walker, John Logan
9/17/2013 | 11-1447 | Erwin Tobar-Barrera v. Eric Holder, Jr. | Roger L. Gregory, Andre M. Davis, Barbara Milano Keenan | Timothy Davis, Jonathan Robbins
9/17/2013 | 12-0342 | Quicken Loans Incorporated v. Phillip Alig | Paul V. Niemeyer, James A. Wynn, Jr., Henry F. Floyd | Meir Feder, John Barrett
9/17/2013 | 12-1953 | Susan Turner v. US | Diana Gribbon Motz, Albert Diaz, John A. Gibney, Jr. | Cynthia Currin, Bruce Ross
9/17/2013 | 12-2091 | Alexander Harris v. Powhatan County School Board | Roger L. Gregory, Andre M. Davis, Barbara Milano Keenan | Barbara Queen, Stacy Haney
9/17/2013 | 12-1156 | Jose Alvarez v. HSBC Bank USA, N.A. | Roger L. Gregory, Andre M. Davis, Barbara Milano Keenan | John Burns, Lartease Tiffith
9/17/2013 | 12-2154 | First South Bank v. Bank of the Ozarks | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | John Lindley III, Alice Paylor
9/17/2013 | 12-4362 | US v. Leroy Hemingway | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | William Nettles IV, Thomas Booth, Justin Antonipillai
9/17/2013 | 12-2367 | Svetlana Kuusk v. Eric Holder, Jr. | Diana Gribbon Motz, Albert Diaz, John A. Gibney, Jr. | Jonathan Greene, Stephen Elliott
9/17/2013 | 12-2370 | L&W Supply Corporation v. Greenway Enterprises, Inc. | J. Harvie Wilkinson III, Allyson K. Duncan, G. Steven Agee | Palmer Hoovestal, James Judkins
9/17/2013 | 12-4176 | US v. Eric Johnson | J. Harvie Wilkinson III, Allyson K. Duncan, G. Steven Agee | Sapna Mirchandani, Debra Dwyer
9/17/2013 | 12-4362 | US v. Leroy Hemingway | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | William Nettles IV, Thomas Booth, Justin Antonipillai
9/17/2013 | 12-4760 | US v. Fabian Montes-Flores | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | Kimberly Albro, Robert Bianchi
9/17/2013 | 13-1021 | Jimmy Radford v. Carolyn W. Colvin | Roger L. Gregory, Andre M. Davis, Barbara Milano Keenan | Samantha Chaifetz, Charlotte Hall
9/17/2013 | 13-1024 | Rickey Carroll v. John Logan | Paul V. Niemeyer, James A. Wynn Jr., Henry F. Floyd | Cortney Walker, John Logan
9/17/2013 | 12-2095 | Nicolas Pastora v. Eric Holder, Jr. | Paul V. Niemeyer, James A. Wynn Jr., Henry F. Floyd | William Heroy, Alison Igoe
9/17/2013 | 12-1953 | Susan Turner v. US | Diana Gribbon Motz, Albert Diaz, John A. Gibney Jr. | Cynthia Currin, Bruce Ross
9/17/2013 | 12-1739 | Mary Johnson v. US | J. Harvie Wilkinson III, Allyson K. Duncan, G. Steven Agee | Diana Schobel, Gretchen Wolfinger
9/17/2013 | 12-1761 | Hartford Fire Insurance Co v. Harleysville Mutual Insurance | J. Harvie Wilkinson III, Allyson K. Duncan, G. Steven Agee | Steven Klepper, David Brown
9/17/2013 | 12-1802 | Dr. Michael Jaffe v. Samsung Electronics Company | Paul V. Niemeyer, James A. Wynn, Jr., Henry F. Floyd | Jeffrey Lamken, William Pratt
9/17/2013 | 11-1447 | Erwin Tobar-Barrera v. Eric Holder, Jr. | Roger L. Gregory, Andre M. Davis, Barbara Milano Keenan | Timothy Davis, Matthew Spurlock
9/17/2013 | 12-1156 | Jose Alvarez v. HSBC Bank USA, N.A. | Roger L. Gregory, Andre M. Davis, Barbara Milano Keenan | John Burns, Lartease Tiffith
9/17/2013 | 12-1739 | Mary Johnson v. US | J. Harvie Wilkinson III, Allyson K. Duncan, G. Steven Agee | Diana Schobel, Gretchen Wolfinger
9/17/2013 | 13-1021 | Jimmy Radford v. Carolyn W. Colvin | Roger L. Gregory, Andre M. Davis, Barbara Milano Keenan | Samantha Chaifetz, Charlotte Hall
9/17/2013 | 12-1802 | Dr. Michael Jaffe v. Samsung Electronics Company | Paul V. Niemeyer, James A. Wynn Jr., Henry F. Floyd | Mark Freeman, Jeffrey Lamken, William Pratt
9/17/2013 | 12-4176 | US v. Eric Johnson | J. Harvie Wilkinson III, Allyson K. Duncan, G. Steven Agee | Thomas Sarachan, Debra Dwyer
9/17/2013 | 12-2091 | Alexander Harris v. Powhatan County School Board | Roger L. Gregory, Andre M. Davis, Barbara Milano Keenan | Barbara Queen, Stacy Haney
9/17/2013 | 12-2095 | Nicolas Pastora v. Eric Holder, Jr. | Paul V. Niemeyer, James A. Wynn Jr., Henry F. Floyd | William Heroy, Alison Igoe
9/17/2013 | 12-2154 | First South Bank v. Bank of the Ozarks | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | John Lindley III, Alice Paylor
9/17/2013 | 12-2366 | Adrian Muldrow v. Schmidt Baking Company, Inc. | Diana Gribbon Motz, Albert Diaz, John A. Gibney Jr. | Jon Gordon, Kathleen Pontone
9/17/2013 | 12-2367 | Svetlana Kuusk v. Eric Holder, Jr. | Diana Gribbon Motz, Albert Diaz, John A. Gibney Jr. | Jonathan Greene, Nicole Murley
9/17/2013 | 12-2370 | L&W Supply Corporation v. Greenway Enterprises, Inc. | J. Harvie Wilkinson III, Allyson K. Duncan, G. Steven Agee | Palmer Hoovestal, James Judkins
9/17/2013 | 12-1761 | Hartford Fire Insurance Co v. Harleysville Mutual Insurance | J. Harvie Wilkinson III, Allyson K. Duncan, G. Steven Agee | Steven Klepper, David Brown
6/25/2013 | 13-1610 | Angelex LTD. v. US | Robert B. King, Henry F. Floyd, Stephanie D. Thacker | Douglas Letter, George Chalos
6/25/2013 | 13-6254 | Gordon Miller v. US | Robert B. King, Albert Diaz, Henry F. Floyd | Ann Hester, Amy Ray, Richard Dietz
5/17/2013 | 12-4346 | US v. Zavier Marquis Davis | Diana Gribbon Motz, Roger L. Gregory, Ellen L. Hollander | Joshua Carpenter, Amy Ray
5/17/2013 | 12-4347 | US v. Troy Baylor | Paul V. Niemeyer, G. Steven Agee, Stephanie D. Thacker | Elizabeth Hanes, Michael Jagels
5/17/2013 | 12-1260 | E. I. DuPont De Nemours & Comp v. Kolon Industries Incorporated | Dennis W. Shedd, Andre M. Davis, Albert Diaz | Paul Clement, Adam Charnes
5/17/2013 | 12-1537 | Town of Nags Head v. Matthew Toloczko | Dennis W. Shedd, Andre M. Davis, Albert Diaz | J. Breemer, Charles Thompson II
5/17/2013 | 12-1538 | Roc Sansotta v. Town of Nags Head | Dennis W. Shedd, Andre M. Davis, Albert Diaz | J. Breemer, Benjamin Gallop, John Leidy
5/17/2013 | 12-1587 | Kolon Industries Incorporated v. E. I. DuPont De Nemours & Comp | Dennis W. Shedd, Andre M. Davis, Albert Diaz | Stephen Kinnaird, Kent Gardiner
5/17/2013 | 12-2123 | Brian Sawyer v. Jim Asbury | Diana Gribbon Motz, Roger L. Gregory, Ellen L. Hollander | Wendy Greve, John Bryan
5/17/2013 | 12-4009 | US v. Ever Medina | J. Harvie Wilkinson III, Allyson K. Duncan, James A. Wynn, Jr. | Patrick Kent, Rod Rosenstein
5/17/2013 | 12-4130 | US v. Jason Scott | Barbara Milano Keenan, Henry F. Floyd, Henry E. Hudson | Marc Hall, Rod Rosenstein
5/17/2013 | 12-4164 | US v. Yooho Weon | Barbara Milano Keenan, Henry F. Floyd, Henry E. Hudson | Paula Xinis, Sujit Raman
5/17/2013 | 12-1065 | Kori Cioca v. Donald Rumsfeld | Paul V. Niemeyer, G. Steven Agee, Stephanie D. Thacker | Susan Burke, Lowell Sturgill Jr.
5/17/2013 | 12-4298 | US v. Gregory Bartko | Barbara Milano Keenan, Henry F. Floyd, Henry E. Hudson | Donald Samuel, Kristine Fritz
5/17/2013 | 12-4433 | US v. Dorothy Anderson | J. Harvie Wilkinson III, Allyson K. Duncan, James A. Wynn Jr. | Jonathan Milling, Jamie Schoen
5/17/2013 | 12-4535 | US v. Courtney Dione Cowan | William B. Traxler, Jr., Robert B. King, Clyde H. Hamilton | Paul Sun Jr., Melissa Rikard
5/17/2013 | 12-4266 | US v. James Lespier | William B. Traxler, Jr., Robert B. King, Clyde H. Hamilton | Milton Widenhouse Jr., Amy Ray
5/17/2013 | 12-4559 | US v. Dana Jackson | Paul V. Niemeyer, G. Steven Agee, Stephanie D. Thacker | Robert Wagner, Erik Siebert
5/17/2013 | 12-4563 | US v. Corey Jones | William B. Traxler, Jr., Robert B. King, Clyde H. Hamilton | Jerome Aquino, Maureen White, Patricia Giles
5/17/2013 | 12-4627 | US v. Naarl Richard | William B. Traxler, Jr., Robert B. King, Clyde H. Hamilton | G. Dickson Jr., Nathan Williams
5/17/2013 | 12-4868 | US v. Charlie Song | Paul V. Niemeyer, G. Steven Agee, Stephanie D. Thacker | Kevin Brehm, Ryan Dickey
5/17/2013 | 12-6021 | US v. Mitchell Smalls | Diana Gribbon Motz, Roger L. Gregory, Ellen L. Hollander | Dylan Greenwood, Richard Cooke
5/17/2013 | 12-6831 | US v. Carlos Ofarrit-Figueroa | Barbara Milano Keenan, Henry F. Floyd, Henry E. Hudson | Eric Brignac, Michael James
5/17/2013 | 12-4263 | US v. Marco Cherry, Jr. | J. Harvie Wilkinson III, Allyson K. Duncan, James A. Wynn, Jr. | Caroline Platt, Sherrie Capotosto
5/17/2013 | 12-4542 | US v. Francis Davis | J. Harvie Wilkinson III, Allyson K. Duncan, James A. Wynn, Jr. | Keith Hurley, Angela Mastandrea-Miller
5/16/2013 | 12-1429 | Waugh Chapel South, LLC v. United Food and Commercial | Robert B. King, Albert Diaz, Henry F. Floyd | Ira Oring, Michael Anderson, Sharon Goodman
5/16/2013 | 11-5204 | US v. Lewis Alston | J. Harvie Wilkinson III, G. Steven Agee, Clyde H. Hamilton | Eric Brignac, Joshua Rogers
5/16/2013 | 11-6945 | James Blakely v. Robert Wards | Wilkinson, Niemeyer, Motz, King, Gregory, Shedd, Duncan, Agee, Davis,Keenan,Wynn,Diaz,Floyd,Thacker | Nilam Sanghvi, Daniel Settana Jr.
5/16/2013 | 12-1350 | James Sanderford v. Duplin Land Development, Inc. | Allyson K. Duncan, Barbara Milano Keenan, David C. Norton | Samuel Potter, Reginald Gillespie Jr.
5/16/2013 | 10-2347 | Liberty University, Inc. v. Jacob Lew | Diana Gribbon Motz, Andre M. Davis, James A. Wynn, Jr. | Mathew Staver, Alisa Klein
5/16/2013 | 12-1671 | Bobby Bland v. B. Roberts | William B. Traxler Jr., Stephanie D. Thacker, Ellen L. Hollander | James Shoemaker Jr., Aaron Panner, Jeff Rosen
5/16/2013 | 12-1832 | Sons of Confederate Veterans v. City of Lexington, Virginia | Robert B. King, Albert Diaz, Henry F. Floyd | Thomas Strelka, Jeremy Carroll
5/16/2013 | 12-6679 | Thomas Moore, Jr. v. Michael Hardee | Allyson K. Duncan, Barbara Milano Keenan, David C. Norton | Clarence DelForge III, Laura Grimaldi
5/16/2013 | 12-2063 | Levert Smith v. Ronald Lusk | Allyson K. Duncan, Barbara Milano Keenan, David C. Norton | Patrick Cassidy, Charles Gould
5/16/2013 | 12-2147 | Kenneth Hensley v. Lillian Koller | Diana Gribbon Motz, Andre M. Davis, James A. Wynn, Jr. | Andrew Lindemann, Timothy Langley
5/16/2013 | 12-4096 | US v. Okechukwo Otuya | J. Harvie Wilkinson III, G. Steven Agee, Clyde H. Hamilton | Marta Kahn, Robert Hur
5/16/2013 | 12-4521 | US v. Timothy Joelette Harris | Paul V. Niemeyer, Roger L. Gregory, Dennis W. Shedd | James Todd Jr., Jennifer May-Parker
5/16/2013 | 12-4772 | US v. Carly Ahlstrom | William B. Traxler Jr., Stephanie D. Thacker, Ellen L. Hollander | Thomas Plofchan Jr., Stacy Bogert
5/16/2013 | 12-1888 | Richard Bunn v. Oldendorff Carriers GmbH & Co. | Diana Gribbon Motz, Andre M. Davis, James A. Wynn, Jr. | Geoffrey Tobias, Bernard Sevel
5/16/2013 | 11-7335 | US v. Calvin Dyess | Paul V. Niemeyer, Roger L. Gregory, Dennis W. Shedd | Jeffrey Brandt, Kimberly Pedersen
5/15/2013 | 12-2059 | Ross Development Corporation v. Fireman's Fund Insurance Co | J. Harvie Wilkinson III, Diana Gribbon Motz, Dennis W. Shedd | Daniel McQueeney Jr., Michael Ginsberg, Michael Kotula, Jay Sever
5/15/2013 | 12-1980 | Roxana Santos v. Frederick County Board of Comm | Andre M. Davis, Andre M. Davis, James A. Wynn Jr., James A. Wynn Jr., Albert Diaz, James R. Spenc | John Hayes Jr., Sandra Lee
5/15/2013 | 12-1952 | American Contractors Indemnity v. Carolina Realty and Developmen | William B. Traxler Jr., Roger L. Gregory, Allyson K. Duncan | Jeff Slagle, John Simmons
5/15/2013 | 12-1935 | Harris Gold v. Gateway Bank, FSB | J. Harvie Wilkinson III, Diana Gribbon Motz, Dennis W. Shedd | Kenneth Oestreicher, James Schroll
5/15/2013 | 12-1928 | Universal Furniture Intl v. Paul Frankel | Sandra Day O'Connor, Henry F. Floyd, Stephanie D. Thacker | John Bloss, W. Wood
5/15/2013 | 12-1791 | State of Maryland v. Universal Elections, Inc. | Robert B. King, G. Steven Agee, David C. Norton | Edward Smith Jr., William Gruhn, Lindsey Powell
5/15/2013 | 12-0005 | Ricky Gray v. Eddie Pearson | Andre M. Davis, James A. Wynn, Jr., Albert Diaz | Robert Lee Jr., Matthew Dullaghan
5/15/2013 | 12-2076 | Steven Thomas v. R. Holly | Paul V. Niemeyer, Barbara Milano Keenan, Clyde H. Hamilton | Bradley Wood, Edward Lewis
5/15/2013 | 12-1662 | Natalia Lopatina v. US | Robert B. King, G. Steven Agee, David C. Norton | Jeffrey Sandberg, Ernest McIntosh Jr.
5/15/2013 | 12-2084 | Steve Cooksey v. Michelle Futrell | Sandra Day O'Connor, Henry F. Floyd, Stephanie D. Thacker | Jeff Rowes, W. Goodman
5/15/2013 | 12-2102 | Metropolitan Regional v. American Home Realty Network | William B. Traxler Jr., Roger L. Gregory, Allyson K. Duncan | Peter Farkas, Margaret Esquenet
5/15/2013 | 12-2244 | General Assurance of America, v. Overby-Seawell Company | Paul V. Niemeyer, Barbara Milano Keenan, Clyde H. Hamilton | J. Evans, J. Fee
5/15/2013 | 12-2296 | Colonial Trading, LLC v. Bassett Furniture Industries | William B. Traxler Jr., Roger L. Gregory, Allyson K. Duncan | Robert Fuller III, June Allison, Pamela Duffy
5/15/2013 | 12-2333 | Barbara Goodman v. Dewayne Barber | Robert B. King, G. Steven Agee, David C. Norton | Torin Fury, Mark Key
5/15/2013 | 12-4725 | US v. Frank Chatmon | J. Harvie Wilkinson III, Diana Gribbon Motz, Dennis W. Shedd | Charles Burnham, Lisa Owings
5/15/2013 | 11-5161 | US v. Herbert DeVaughn | J. Harvie Wilkinson III, Diana Gribbon Motz, Dennis W. Shedd | Scott Brown, Zelda Wesley
5/15/2013 | 12-6839 | US v. Michael Pardee | Paul V. Niemeyer, Barbara Milano Keenan, Clyde H. Hamilton | G. DuBois, Michael James
5/15/2013 | 12-2096 | Michael Corey v. HUD | Andre M. Davis, James A. Wynn, Jr., Albert Diaz | Frederick Holroyd II, Christopher Wang
5/15/2013 | 12-6146 | US v. Mikel Bolander | Paul V. Niemeyer, Barbara Milano Keenan, Clyde H. Hamilton | Walter Paramore III, Edward Gray
5/15/2013 | 12-2188 | E.D. v. Pfizer, Incorporated | Sandra Day O'Connor, Henry F. Floyd, Stephanie D. Thacker | Mark Cheffo, Anthony Majestro
5/14/2013 | 12-1795 | Melissa Bediako v. American Honda Finance | Sandra Day O'Connor, James A. Wynn, Jr., Albert Diaz | Cory Zajdel, Donald Falk
5/14/2013 | 12-7301 | US v. Terrence Smith | William B. Traxler, Jr., Paul V. Niemeyer, Henry F. Floyd | C. Brown, Albert Copperthite
5/14/2013 | 12-6624 | US v. Mario Baker | J. Harvie Wilkinson III, Roger L. Gregory, Barbara Milano Keenan | John Akin, Neal Walters, Michael Murray
5/14/2013 | 12-6212 | Jason King v. US | J. Harvie Wilkinson III, Roger L. Gregory, Barbara Milano Keenan | Stephanie Taylor, John Gianola
5/14/2013 | 12-4652 | US v. Mohammad Shibin | Paul V. Niemeyer, Diana Gribbon Motz, Henry F. Floyd , | James Broccoletti, Benjamin Hatch
5/14/2013 | 12-1819 | Kelly Capital, LLC v. S&M Brands, Incorporated | Paul V. Niemeyer, Diana Gribbon Motz, Henry F. Floyd , | David Barmak, Bryan Haynes
5/14/2013 | 12-1610 | Luanna Scott v. Family Dollar Stores, Inc. | J. Harvie Wilkinson III, Roger L. Gregory, Barbara Milano Keenan | Robert Wiggins Jr., John Wester
5/14/2013 | 11-2038 | Eastern Associated Coal Corpor v. DOWCP | J. Harvie Wilkinson III, Roger L. Gregory, Barbara Milano Keenan | Laura Klaus, Ryan Gilligan
5/14/2013 | 11-7354 | John Moss, III v. David Ballard | Sandra Day O'Connor, James A. Wynn, Jr., Albert Diaz | Neal Walters, Stuart McCommas, Robert Goldberg
5/14/2013 | 11-2327 | James Dunlap v. Cottman Transmission Systems | Sandra Day O'Connor, James A. Wynn, Jr., Albert Diaz | Peter Rutledge, Crystal Johnson, James Rubinger
5/14/2013 | 11-5167 | US v. Genaro Flores-Duran | Paul V. Niemeyer, Diana Gribbon Motz, Henry F. Floyd | Geoffrey Hosford, Kristine Fritz
5/14/2013 | 12-2183 | Educational Media Co at VT v. J. Insley | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | Rebecca Glenberg, Catherine Hill
5/14/2013 | 12-1369 | United States ex rel Kurt Bunk v. Gosselin World Wide Moving, N. | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | Michael Anderson, Jeffrey Clair , Kerri Ruttenberg
5/14/2013 | 11-2118 | Jennifer Clodfelter v. Republic of Sudan | Allyson K. Duncan, G. Steven Agee, Andre M. Davis | Andrew Hall, Adam Jed
5/14/2013 | 12-1096 | US v. State of South Carolina | Allyson K. Duncan, G. Steven Agee, Andre M. Davis | James Smith Jr., Daniel Tenny, Karen Tumlin
5/14/2013 | 12-1367 | Margaret Littlepaige v. US | Allyson K. Duncan, G. Steven Agee, Andre M. Davis | Peter Sarda, Shailika Shah
3/28/2013 | 12-4442 | US v. Nawaf Hasan | Roger L. Gregory, Allyson K. Duncan, G. Steven Agee | Marvin Miller, Richard Cooke
3/28/2013 | 12-2196 | Lance Swick v. James Wilde | Roger L. Gregory, Allyson K. Duncan, G. Steven Agee | Dan Hartzog, Robert Ekstrand
3/28/2013 | 12-1944 | Otis Hill v. Southeastern Freight Lines | Roger L. Gregory, Allyson K. Duncan, G. Steven Agee | Norman Smith, William Duda
3/22/2013 | 12-4088 | US v. Jervis Davis | William B. Traxler, Jr., Diana Gribbon Motz, James A. Wynn, Jr. | Marilyn Ozer, Kristine Fritz
3/22/2013 | 12-1764 | SC Dept of Education v. US Secretary of Education | Paul V. Niemeyer, G. Steven Agee, Stephanie D. Thacker | Shelly Kelly, Alisa Klein
3/22/2013 | 12-1573 | Lamont Wilson v. Dollar General Corporation | Paul V. Niemeyer, G. Steven Agee, Stephanie D. Thacker | Terry Grimes, Douglas Haloftis
3/22/2013 | 12-4168 | US v. Raymond Allen | Robert B. King, Roger L. Gregory, Barbara Milano Keenan | Aaron Michel, Amy Ray
3/22/2013 | 12-1496 | Sloan Pleasants v. Town of Louisa | Dennis W. Shedd, Henry F. Floyd, Joseph R. Goodwin | Jeffrey Fogel, Maurice Fisher Jr., Steven Rosenfield
3/22/2013 | 12-1786 | B. Shenoy v. Charlotte-Mecklenburg Hospital | Dennis W. Shedd, Henry F. Floyd, Joseph R. Goodwin | Mark Prak, Charles Johnson, William Sturges
3/22/2013 | 12-1266 | Charles Smalley v. Shapiro & Burson, LLP | J. Harvie Wilkinson III, Andre M. Davis, Jackson L. Kiser | Ian Stumpf, Robert Scott, William Carter
3/22/2013 | 11-2131 | Solomon Stratton v. Mecklenburg Co Social Services | Robert B. King, Roger L. Gregory, Barbara Milano Keenan | Lucas Bradley, Robert Harrington, Robert Adden Jr.
3/22/2013 | 12-1514 | NLRB v. Enterprise Leasing Company | Allyson K. Duncan, Albert Diaz, Clyde H. Hamilton | Daniel Begian, Gregory Robertson, Michael Shebelskie ,John Hasman, Beth Brinkmann, David Seid, Robert Englehart , James Coppess
3/22/2013 | 12-4308 | US v. Alvin Stallins | William B. Traxler, Jr., Diana Gribbon Motz, James A. Wynn, Jr. | Frances Pratt, Michael Murray
3/22/2013 | 12-4363 | US v. Abduladhim Ahmed Al Sabahi | Dennis W. Shedd, Henry F. Floyd, Joseph R. Goodwin | Jorgelina Araneda, Joshua Rogers
3/22/2013 | 12-4419 | US v. Pedro Escobar-Marroquin | William B. Traxler, Jr., Diana Gribbon Motz, James A. Wynn, Jr. | Caroline Platt, Stephen Schiller
3/22/2013 | 12-1882 | Ronnie Dooley v. Hartford Accident & Indemnity | Robert B. King, Roger L. Gregory, Barbara Milano Keenan | John Rasmussen, John Mumford Jr.
3/22/2013 | 11-1839 | Westmoreland Coal Company v. Jarrell Cochran | William B. Traxler Jr., Diana Gribbon Motz, James A. Wynn Jr. | Thomas Hancock, Ryan Gilligan, Jeffrey Goldberg
3/22/2013 | 11-4295 | US v. Cashmere Cazeau | J. Harvie Wilkinson III, Andre M. Davis, Jackson L. Kiser | Bettina Roberts, Jennifer May-Parker
3/22/2013 | 12-4515 | US v. Jared Baraloto | Robert B. King, Roger L. Gregory, Barbara Milano Keenan | Steven Levin, Sujit Raman, Michael Pusateri
3/22/2013 | 12-4603 | US v. Marcel Aparicio-Soria | J. Harvie Wilkinson III, Andre M. Davis, Jackson L. Kiser | Sapna Mirchandani, Paul Nitze
3/22/2013 | 12-6705 | Demetrius Hill v. C. O. Crum | Paul V. Niemeyer, G. Steven Agee, Stephanie D. Thacker | James O'Keeffe IV, Arlene Sokolowski
3/22/2013 | 12-4477 | US v. James Ashford | Allyson K. Duncan, Albert Diaz, Clyde H. Hamilton | Kimberly Albro, Robert Daley Jr.
3/22/2013 | 12-1480 | Carpenters Pension Fund v. Maryland Department of Health | Allyson K. Duncan, Albert Diaz, Clyde H. Hamilton | William Brockman, Brian Esders
3/21/2013 | 12-1628 | Lonnie Gilliland v. Charles Co Board of Education | William B. Traxler, Jr., Dennis W. Shedd, David A. Faber | Edmund O'Meally, Scott Conwell
3/21/2013 | 12-4336 | US v. Eric Giles | Diana Gribbon Motz, Diana Gribbon Motz, Allyson K. Duncan, Allyson K. Duncan, Arenda Wright Alle | Carol Bauer, William Auman, William Miller
3/21/2013 | 12-1805 | Michael Field, Jr. v. Michael Berman | Roger L. Gregory, Stephanie D. Thacker, Clyde H. Hamilton | William Snow, Jeffrey Harab
3/21/2013 | 12-1747 | Duane Minnick v. County of Currituck | J. Harvie Wilkinson III, Robert B. King, James A. Wynn, Jr. | Megan Mechak, Paul Derrick, Jacqueline Hughes , Jeffrey Doyle
3/21/2013 | 12-1591 | CVLR Performance Horses, Inc. v. John Wynne | William B. Traxler Jr., Dennis W. Shedd, David A. Faber | Gary Bowman, Chad Mooney
3/21/2013 | 12-1680 | Manuel Coreas v. Eric Holder, Jr. | G. Steven Agee, Barbara Milano Keenan, Henry F. Floyd | Manuel Rivera Jr., Bernard Joseph
3/21/2013 | 12-1674 | ABB INC. v. CSX Transportation, Inc. | G. Steven Agee, Barbara Milano Keenan, Henry F. Floyd | Jeffrey Young, Hyman Hillenbrand
3/21/2013 | 11-1966 | George Lutfi v. US | Roger L. Gregory, Stephanie D. Thacker, Clyde H. Hamilton | Steven Oster, Joseph Krill
3/21/2013 | 12-1575 | L.S. v. Pamela Shipman | J. Harvie Wilkinson III, Robert B. King, James A. Wynn, Jr. | Wallace Hollowell III, Douglas Sea
3/21/2013 | 12-1790 | Martin Whiteman v. Chesapeake Appalachia, LLC | William B. Traxler, Jr., Dennis W. Shedd, David A. Faber | Joseph Lovett, Timothy Miller
3/21/2013 | 11-1966 | George Lutfi v. US | Roger L. Gregory, Stephanie D. Thacker, Clyde H. Hamilton | Steven Oster, Joseph Krill
3/21/2013 | 11-2418 | Mingo Logan Coal Co. v. Owens | Paul V. Niemeyer, Andre M. Davis, Albert Diaz | William Mattingly, John Cline, Sarah Hurley
3/21/2013 | 12-1244 | Bon-Air Partnership v. Robert Trumble | Diana Gribbon Motz, Allyson K. Duncan, Robert E. Payne | John Simpson, Mary Binns-Davis
3/21/2013 | 12-1294 | Union Carbide Corporation v. Virginia Richards | Paul V. Niemeyer, Andre M. Davis, Albert Diaz | Kathy Snyder , Mark Solomons , Ryan Gilligan, Barry Joyner
3/21/2013 | 12-1575 | L.S. v. Pamela Shipman | J. Harvie Wilkinson III, Robert B. King, James A. Wynn Jr. | Wallace Hollowell III, Douglas Sea
3/21/2013 | 12-1649 | Pagidipati Enterprises, Inc. v. Laboratory Corp of America | Diana Gribbon Motz, Allyson K. Duncan, Robert E. Payne | Robert Steiner, Reid Phillips
3/21/2013 | 12-1805 | Michael Field, Jr. v. Michael Berman | Roger L. Gregory, Stephanie D. Thacker, Clyde H. Hamilton | William Snow, Jeffrey Harab
3/21/2013 | 12-1682 | T-Mobile Northeast LLC v. Howard County Board of Appeals | J. Harvie Wilkinson III, Robert B. King, James A. Wynn, Jr. | Thomas Thompson, Melissa Whipkey
3/21/2013 | 12-1680 | Manuel Coreas v. Eric Holder, Jr. | G. Steven Agee, Barbara Milano Keenan, Henry F. Floyd | Manuel Rivera Jr., Bernard Joseph
3/21/2013 | 12-1682 | T-Mobile Northeast LLC v. Howard County Board of Appeals | J. Harvie Wilkinson III, Robert B. King, James A. Wynn, Jr. | Thomas Thompson, Melissa Whipkey
3/21/2013 | 12-1674 | ABB INC. v. CSX Transportation, Inc. | G. Steven Agee, Barbara Milano Keenan, Henry F. Floyd | Jeffrey Young, Hyman Hillenbrand
3/21/2013 | 11-2418 | Mingo Logan Coal Co. v. Owens | Paul V. Niemeyer, Andre M. Davis, Albert Diaz | William Mattingly, John Cline, Sarah Hurley
3/21/2013 | 12-1649 | Pagidipati Enterprises, Inc. v. Laboratory Corp of America | Diana Gribbon Motz, Diana Gribbon Motz, Allyson K. Duncan, Allyson K. Duncan, Arenda Wright Alle | Robert Steiner, Reid Phillips
3/21/2013 | 12-1747 | Duane Minnick v. County of Currituck | J. Harvie Wilkinson III, Robert B. King, James A. Wynn, Jr. | Megan Mechak, Paul Derrick, Jeffrey Doyle, Jacqueline Hughes
3/21/2013 | 12-1790 | Martin Whiteman v. Chesapeake Appalachia, LLC | William B. Traxler Jr., Dennis W. Shedd, David A. Faber | Joseph Lovett, Timothy Miller
3/21/2013 | 12-4336 | US v. Eric Giles | Diana Gribbon Motz, Allyson K. Duncan, Robert E. Payne | Carol Bauer, William Auman, William Miller
3/21/2013 | 12-1628 | Lonnie Gilliland v. Charles Co Board of Education | William B. Traxler, Jr., Dennis W. Shedd, David A. Faber | Edmund O'Meally, Scott Conwell
3/21/2013 | 12-1294 | Union Carbide Corporation v. Virginia Richards | Paul V. Niemeyer, Andre M. Davis, Albert Diaz | Kathy Snyder, Ryan Gilligan, Barry Joyner, Mark Solomons
3/21/2013 | 12-1591 | CVLR Performance Horses, Inc. v. John Wynne | William B. Traxler, Jr., Dennis W. Shedd, David A. Faber | Gary Bowman, Chad Mooney
3/21/2013 | 12-1635 | Mary DiFederico v. Marriott International, Incorp | Roger L. Gregory, Stephanie D. Thacker, Clyde H. Hamilton | Andrew Hall, Paul Leary Jr.
3/21/2013 | 12-1244 | Bon-Air Partnership v. Robert Trumble | Diana Gribbon Motz, Diana Gribbon Motz, Allyson K. Duncan, Allyson K. Duncan, Arenda Wright Alle | John Simpson, Mary Binns-Davis
3/21/2013 | 12-1635 | Mary DiFederico v. Marriott International, Incorp | Roger L. Gregory, Stephanie D. Thacker, Clyde H. Hamilton | Andrew Hall, Paul Leary Jr.
3/20/2013 | 12-1566 | Marine Repair Services, Inc v. Christopher Fifer | J. Harvie Wilkinson III, Dennis W. Shedd, Allyson K. Duncan | Lawrence Postol, Michael Perticone
3/20/2013 | 12-1740 | Agape Motorcoach Retreat, LLC v. Glenda Brintle | Paul V. Niemeyer, Diana Gribbon Motz, Barbara Milano Keenan | Wells Byrnes Sr., Thomas Eckert, Alan Caudell
3/20/2013 | 12-1723 | Gerald Lembach v. Howard Bierman | Robert B. King, Albert Diaz, Henry F. Floyd | Scott Borison, J. Schraub
3/20/2013 | 12-1722 | Oakley Baldwin v. City of Greensboro | Andre M. Davis, Stephanie D. Thacker, Mark S. Davis | Gregory Kash, Grover Wilson
3/20/2013 | 12-1621 | SG Homes Associates, LP v. Michael Marinucci | Roger L. Gregory, G. Steven Agee, David A. Faber | Jeffrey Forman, Steven Gould
3/20/2013 | 12-1352 | Thomas Davis v. MPW Industrial Services, Inc. | William B. Traxler, Jr., James A. Wynn, Jr., Clyde H. Hamilton | William Arnold, Phillip Kilgore
3/20/2013 | 12-1287 | Mygallons LLC v. U.S. Bancorp | Paul V. Niemeyer, Diana Gribbon Motz, Barbara Milano Keenan | Gary Jackson, Johnny Loper
3/20/2013 | 11-2202 | Jacob Scoggins v. Lee's Crossing Homeowners | Paul V. Niemeyer, Diana Gribbon Motz, Barbara Milano Keenan | Charles Ferguson, Michael Dingman
3/20/2013 | 12-4211 | US v. Jermar Jones | Robert B. King, Albert Diaz, Henry F. Floyd | James Theuer, Randy Stoker
3/20/2013 | 12-1143 | VRCompliance LLC v. Homeaway, Inc. | J. Harvie Wilkinson III, Dennis W. Shedd, Allyson K. Duncan | M. Blankenship, Adam Kessel
3/20/2013 | 12-1705 | Mobolaji Aoko v. Eric Holder, Jr. | Andre M. Davis, Stephanie D. Thacker, Mark S. Davis | Fatai Suleman, Robert Stalzer
3/20/2013 | 12-1899 | Anthony Dash v. Floyd Mayweather, Jr. | Andre M. Davis, Stephanie D. Thacker, Mark S. Davis | William McKinnon, Mark Tratos, Jerry McDevitt
3/20/2013 | 12-4323 | US v. Michael Ecklin | William B. Traxler, Jr., James A. Wynn, Jr., Clyde H. Hamilton | Kim Crump, Paul Watson, Benjamin Hatch
3/20/2013 | 12-4155 | US v. Tyre Johnson | William B. Traxler, Jr., James A. Wynn, Jr., Clyde H. Hamilton | Matthew Greene, Olivia Norman
3/20/2013 | 12-2017 | Robert Ranta v. Thomas Gorman | Roger L. Gregory, G. Steven Agee, David A. Faber | Daniel Press, Eva Choi
3/20/2013 | 12-1996 | Libertarian Party of Virginia v. Charles Judd | Robert B. King, Albert Diaz, Henry F. Floyd | Earle Getchell Jr., Rebecca Glenberg
3/20/2013 | 12-1973 | Josephine Spaulding v. Wells Fargo Bank, N.A. | Andre M. Davis, Stephanie D. Thacker, Mark S. Davis | Jason Ostendorf, Virginia Barnhart
3/20/2013 | 12-1922 | Carlin Robinson v. Daniel Lioi | Roger L. Gregory, G. Steven Agee, David A. Faber | James Fields, Cary Hansel III
3/20/2013 | 12-1910 | Stephanie Crockett v. Mission Hospital, Inc. | Roger L. Gregory, G. Steven Agee, David A. Faber | George Moore, Jonathan Yarbrough
3/20/2013 | 12-6687 | Billy Tedder v. Sgt. Johnson | William B. Traxler, Jr., James A. Wynn, Jr., Clyde H. Hamilton | Thomas Davies, Walker Willcox
3/20/2013 | 12-1835 | Malcolm White v. Soudabeh White | Paul V. Niemeyer, Diana Gribbon Motz, Barbara Milano Keenan | Stephen Cullen, Michael Johnson
3/19/2013 | 12-1588 | Federal Deposit Insurance Corp v. Avery Cashion, III | Diana Gribbon Motz, Robert B. King, G. Steven Agee | Edward Bleynat Jr., Esther Manheimer
3/19/2013 | 11-1999 | John Coleman v. DEA | William B. Traxler, Jr., J. Harvie Wilkinson III, Paul V. Niemeyer | Daniel Stotter, David Moskowitz
3/19/2013 | 11-2167 | Agustin Pantoja-Medrano v. Eric Holder, Jr. | Diana Gribbon Motz, Robert B. King, G. Steven Agee | Parker Clote, Holly Smith
3/19/2013 | 11-6940 | Jerome Williams v. Jon Ozmint | Dennis W. Shedd, Andre M. Davis, Barbara Milano Keenan | Kirsten Small, Andrew Lindemann
3/19/2013 | 12-1590 | Petr Bocek v. JGA Associates, LLC | William B. Traxler Jr., J. Harvie Wilkinson III, Paul V. Niemeyer | S. Salb, Brian Athey, David Sher
3/19/2013 | 12-1476 | Barry Gainsburg v. Steben & Co., Inc. | William B. Traxler, Jr., J. Harvie Wilkinson III, Paul V. Niemeyer | Philip Sweitzer, Eric Hemmendinger
3/19/2013 | 12-6373 | Jean Germain v. Bobby Shearin | Roger L. Gregory, James A. Wynn Jr., Albert Diaz | Scott Martin, Siobhan Madison
3/19/2013 | 12-1351 | Vigilant Insurance Company v. McKenney's Inc | Dennis W. Shedd, Andre M. Davis, Barbara Milano Keenan | Thomas Higgins Jr., Kimila Wooten
3/19/2013 | 12-1757 | Chamber of Commerce v. NLRB | Allyson K. Duncan, Henry F. Floyd, Stephanie D. Thacker | Dawn Goldstein, Lemuel Geddie Jr.
3/19/2013 | 12-1999 | Ohio Valley Environmental Coal v. US Army Corps of Eng | William B. Traxler Jr., J. Harvie Wilkinson III, Paul V. Niemeyer | Joseph Lovett, Michael Gray, Robert McLusky
3/19/2013 | 12-2074 | The Country Vintner of NC v. E & J Gallo Winery | Dennis W. Shedd, Andre M. Davis, Barbara Milano Keenan | Jonathan Bumgarner, Garrick Sevilla, Stephen Busch
3/19/2013 | 12-6129 | US v. Marcus McNeill | Roger L. Gregory, James A. Wynn Jr., Albert Diaz | Andrew Barr, Shailika Shah
3/19/2013 | 12-6738 | US v. Donald Snyder | Roger L. Gregory, James A. Wynn Jr., Albert Diaz | James Craven III, Jennifer Dannels
3/19/2013 | 12-1533 | Martha Wellman v. Bobcat Oil & Gas, Inc. | Allyson K. Duncan, Henry F. Floyd, Stephanie D. Thacker | Jason Poling, Matthew Perry , Robert Waters
3/19/2013 | 12-1581 | Minnesota Lawyers Mutual Ins. v. Baylor & Jackson, PLLC | Allyson K. Duncan, Henry F. Floyd, Stephanie D. Thacker | Joseph Creed, Paul Farquharson
3/19/2013 | 12-4402 | US v. Trino Medina-Campo | Diana Gribbon Motz, Robert B. King, G. Steven Agee | Paresh Patel, Roger Picker
3/19/2013 | 11-1999 | John Coleman v. DEA | William B. Traxler Jr., J. Harvie Wilkinson III, Paul V. Niemeyer | Daniel Stotter, David Moskowitz
3/19/2013 | 12-1351 | Vigilant Insurance Company v. McKenney's Inc | Dennis W. Shedd, Andre M. Davis, Barbara Milano Keenan | Thomas Higgins Jr., Kimila Wooten
3/19/2013 | 12-1476 | Barry Gainsburg v. Steben & Co., Inc. | William B. Traxler Jr., J. Harvie Wilkinson III, Paul V. Niemeyer | Philip Sweitzer, Eric Hemmendinger
3/19/2013 | 12-1533 | Martha Wellman v. Bobcat Oil & Gas, Inc. | Allyson K. Duncan, Henry F. Floyd, Stephanie D. Thacker | Jason Poling, Robert Waters, Matthew Perry
3/19/2013 | 12-1544 | Branell Harris v. Reston Hospital Center, LLC | Allyson K. Duncan, Henry F. Floyd, Stephanie D. Thacker | Annette Rubin, Sarah Belger
3/19/2013 | 12-1581 | Minnesota Lawyers Mutual Ins. v. Baylor & Jackson, PLLC | Allyson K. Duncan, Henry F. Floyd, Stephanie D. Thacker | Joseph Creed, Paul Farquharson
3/19/2013 | 12-1590 | Petr Bocek v. JGA Associates, LLC | William B. Traxler, Jr., J. Harvie Wilkinson III, Paul V. Niemeyer | S. Salb , David Sher, Brian Athey
3/19/2013 | 11-2167 | Agustin Pantoja-Medrano v. Eric Holder, Jr. | Diana Gribbon Motz, Robert B. King, G. Steven Agee | Parker Clote, Holly Smith
3/19/2013 | 12-6738 | US v. Donald Snyder | Roger L. Gregory, James A. Wynn, Jr., Albert Diaz | James Craven III, Jennifer Dannels
3/19/2013 | 12-2074 | The Country Vintner of NC v. E & J Gallo Winery | Dennis W. Shedd, Andre M. Davis, Barbara Milano Keenan | Garrick Sevilla, Stephen Busch, Jonathan Bumgarner
3/19/2013 | 12-1544 | Branell Harris v. Reston Hospital Center, LLC | Allyson K. Duncan, Henry F. Floyd, Stephanie D. Thacker | Annette Rubin, Sarah Belger
3/19/2013 | 12-1588 | Federal Deposit Insurance Corp v. Avery Cashion, III | Diana Gribbon Motz, Robert B. King, G. Steven Agee | Edward Bleynat Jr., Esther Manheimer
3/19/2013 | 11-6940 | Jerome Williams v. Jon Ozmint | Dennis W. Shedd, Andre M. Davis, Barbara Milano Keenan | Kirsten Small, Andrew Lindemann
3/19/2013 | 12-1999 | Ohio Valley Environmental Coal v. US Army Corps of Eng | William B. Traxler, Jr., J. Harvie Wilkinson III, Paul V. Niemeyer | Joseph Lovett, Michael Gray, Robert McLusky
3/19/2013 | 12-6373 | Jean Germain v. Bobby Shearin | Roger L. Gregory, James A. Wynn, Jr., Albert Diaz | Scott Martin, Siobhan Madison
3/19/2013 | 12-4402 | US v. Trino Medina-Campo | Diana Gribbon Motz, Robert B. King, G. Steven Agee | Paresh Patel, Roger Picker
3/19/2013 | 12-6129 | US v. Marcus McNeill | Roger L. Gregory, James A. Wynn, Jr., Albert Diaz | Andrew Barr, Shailika Shah
3/19/2013 | 12-1757 | Chamber of Commerce v. NLRB | Allyson K. Duncan, Henry F. Floyd, Stephanie D. Thacker | Dawn Goldstein, Lemuel Geddie Jr.
2/21/2013 | 12-1288 | Toni Works v. Michael Astrue | William B. Traxler, Jr., Barbara Milano Keenan, Stephanie D. Thacker | Richard Seymour, Jason Medinger
2/21/2013 | 12-1288 | Toni Works v. Michael Astrue | William B. Traxler Jr., Barbara Milano Keenan, Stephanie D. Thacker | Richard Seymour, Jason Medinger
2/1/2013 | 12-1128 | Logan & Kanawha Coal Company v. Detherage Coal Sales, Inc. | Paul V. Niemeyer, Allyson K. Duncan, Albert Diaz | Rodney Smith, D. Cook
2/1/2013 | 12-4081 | US v. Christopher Bell | Paul V. Niemeyer, Allyson K. Duncan, Albert Diaz | Russell Mace III, John Rowell
2/1/2013 | 11-4676 | US v. Johnny Beason | J. Harvie Wilkinson III, Henry F. Floyd, Joseph R. Goodwin | Kristen Leddy, Brandon Flower
2/1/2013 | 11-5130 | US v. John McLean | Diana Gribbon Motz, Roger L. Gregory, Barbara Milano Keenan, Roger L. Gregory, Barbara Milano Ke | Richard Westling, Sandra Wilkinson
2/1/2013 | 11-5191 | US v. Javaad Fisher | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | Elizabeth Hanes, Roderick Young
2/1/2013 | 12-4118 | US v. Sargis Tadevosyan | Paul V. Niemeyer, Allyson K. Duncan, Albert Diaz | A. Craig, Tony Mirvis, Meredith Thomas
2/1/2013 | 12-4408 | US v. Eduardo Rangel-Castaneda | J. Harvie Wilkinson III, Henry F. Floyd, Joseph R. Goodwin | Joshua Carpenter, William Miller
2/1/2013 | 12-4047 | US v. Winston Oliver, II | J. Harvie Wilkinson III, Henry F. Floyd, Joseph R. Goodwin | Christopher Collins , Mark Bodner, Erik Siebert
2/1/2013 | 12-4248 | US v. Joseph Hall | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | Edward Gillison Jr., David Perri
2/1/2013 | 12-1334 | Frederick Aikens v. William Ingram, Jr. | Robert B. King, Dennis W. Shedd, Stephanie D. Thacker | William Webb Sr., Jess Mekeel
2/1/2013 | 12-4062 | US v. James Whitley | Diana Gribbon Motz, Roger L. Gregory, Barbara Milano Keenan, Roger L. Gregory, Barbara Milano Ke | James Hawes, Jennifer May-Parker
2/1/2013 | 12-4010 | US v. Sean Price | Diana Gribbon Motz, Roger L. Gregory, Barbara Milano Keenan, Roger L. Gregory, Barbara Milano Ke | Kristen Leddy, Robert McWilliams Jr.
2/1/2013 | 12-1458 | Clifton LLC v. Dewey Tadlock | J. Harvie Wilkinson III, Henry F. Floyd, Joseph R. Goodwin | Troy Lambert, Wallace Jordan Jr.
2/1/2013 | 12-1444 | Georgia Pacific Consumer v. Von Drehle Corporation | Diana Gribbon Motz, Roger L. Gregory, Barbara Milano Keenan, Roger L. Gregory, Barbara Milano Ke | Miguel Estrada, Michael Thomas
2/1/2013 | 12-4396 | US v. Theophilus Akwei | Paul V. Niemeyer, Allyson K. Duncan, Albert Diaz | Gregory Stambaugh, James Gillis
1/31/2013 | 11-1816 | Larry Mayo v. Board of Education | Paul V. Niemeyer, Roger L. Gregory, Andre M. Davis | Richard Seymour, Abbey Hairston, Mark Murphy
1/31/2013 | 11-4817 | US v. Michael Woods | William B. Traxler, Jr., Barbara Milano Keenan, Stephanie D. Thacker | Douglas Kingsbery, Yvonne Watford-McKinney
1/31/2013 | 08-0004 | US v. Thomas Hager | Allyson K. Duncan, James A. Wynn, Jr., Henry F. Floyd | Barry Fisher, James Trump
1/31/2013 | 11-1124 | Tenisha Jiggets v. Christopher Long | Paul V. Niemeyer, Roger L. Gregory, Andre M. Davis | John Breads Jr., Donald Temple
1/31/2013 | 11-2220 | Municipal Association of SC v. USAA General Indemnity Company | Paul V. Niemeyer, Roger L. Gregory, Andre M. Davis | Robert Jordan, Robert Tyson Jr., Molly Cherry
1/31/2013 | 11-2386 | Anne Collins v. Baltimore City Board of School | J. Harvie Wilkinson III, Dennis W. Shedd, Albert Diaz | John Stolarz, Leslie Stellman
1/31/2013 | 12-1346 | 2300 Pennsylvania Avenue, LLC v. Harkins Builders, Incorporated | Diana Gribbon Motz, Robert B. King, G. Steven Agee | William Mauck Jr., Patricia Millett
1/31/2013 | 12-6650 | US v. Gary Gaynor | Diana Gribbon Motz, Robert B. King, G. Steven Agee | G. DuBois, Kristine Fritz
1/31/2013 | 12-6590 | US v. Robert Mann | Diana Gribbon Motz, Robert B. King, G. Steven Agee | Richard Cooke, Caroline Platt
1/31/2013 | 12-4547 | US v. Joe Lanning | Allyson K. Duncan, James A. Wynn, Jr., Henry F. Floyd | Ann Hester, Amy Ray
1/31/2013 | 12-4108 | US v. Arturo Castellanos | William B. Traxler, Jr., G. Steven Agee, Andre M. Davis | Michael Archenbronn, Sandra Hairston
1/31/2013 | 12-1632 | Melissa H. Trail v. Local 2850 UAW | J. Harvie Wilkinson III, Dennis W. Shedd, Albert Diaz | Richard Hawkins III, Robert Paul
1/31/2013 | 11-5061 | US v. Jose Juarez-Santamaria | William B. Traxler, Jr., Barbara Milano Keenan, Stephanie D. Thacker | Eugene Gorokhov, Patricia Giles
1/31/2013 | 12-1201 | Karen Balas v. Huntington Ingalls Industries | Allyson K. Duncan, James A. Wynn, Jr., Henry F. Floyd | Steven Biss, Scott Kezman
1/31/2013 | 12-1195 | Mary LaClair v. Suburban Hospital, Incorporate | William B. Traxler, Jr., Barbara Milano Keenan, Stephanie D. Thacker | Patrick Regan, Michael von Diezelski
1/31/2013 | 09-5067 | US v. William Graham | William B. Traxler, Jr., G. Steven Agee, Andre M. Davis | Michael Wein, Michael Hanlon
1/31/2013 | 12-1181 | Charlotte McCauley v. Home Loan Investment Bank, FSB | Allyson K. Duncan, James A. Wynn, Jr., Henry F. Floyd | Bren Pomponio, R. Rodgers
1/31/2013 | 12-1078 | American Petroleum Institute v. Roy Cooper, III | Diana Gribbon Motz, Robert B. King, G. Steven Agee | Robert Long Jr., Melissa Trippe, Charles Marshall III
1/31/2013 | 12-1022 | NLRB v. Daycon Products Company, Inc. | Paul V. Niemeyer, Roger L. Gregory, Andre M. Davis | Paul Rosenberg , Barbara Sheehy,John Mooney
1/30/2013 | 12-1103 | Kenneth Ackerman v. ExxonMobil Corporation | William B. Traxler Jr., Roger L. Gregory, Allyson K. Duncan | Andrew Gendron, Paul Raschke
1/30/2013 | 11-2406 | Project Honey Pot v. Andrey Chernuk | Paul V. Niemeyer, Dennis W. Shedd, G. Steven Agee | Jon Praed, Craig Whitney, Andrew Sherrod
1/30/2013 | 11-2195 | Victoria Anderson v. Discovery Communications, LLC | Paul V. Niemeyer, Dennis W. Shedd, G. Steven Agee | Elaine Fitch, Mark Harris
1/30/2013 | 11-1879 | Arthur Galloway v. Horne Concrete Construction | Diana Gribbon Motz, Robert B. King, Henry F. Floyd | Gregory Lattimer, James Liskow
1/30/2013 | 11-4649 | US v. Derrick McCaskey | William B. Traxler Jr., Roger L. Gregory, Allyson K. Duncan | Neal Rosensweig, Yvonne Watford-McKinney
1/30/2013 | 12-7687 | US v. Frederick Springer | J. Harvie Wilkinson III, Barbara Milano Keenan, James A. Wynn Jr. | Benjamin Shultz, Eric Brignac
1/30/2013 | 12-1053 | Raymond James Financial v. Peter Cary | J. Harvie Wilkinson III, Barbara Milano Keenan, James A. Wynn, Jr. | John Chapman, Stephen Cochran
1/30/2013 | 12-1728 | Scott Andochick v. Ronald Byrd | Diana Gribbon Motz, Robert B. King, Henry F. Floyd | George Peterson, Karl Pilger
1/30/2013 | 12-1563 | Thomas Francis v. Allstate Insurance Company | Andre M. Davis, Albert Diaz, Stephanie D. Thacker | Edward Brown, Ronald Cox Jr.
1/30/2013 | 12-1445 | C. H. v. Martha Heyward | Paul V. Niemeyer, Dennis W. Shedd, G. Steven Agee | Kirk David Lyons, Vinton D. Lide, Vernie L. Williams
1/30/2013 | 12-1321 | US v. 4219 University Drive, Fairfax | J. Harvie Wilkinson III, Barbara Milano Keenan, James A. Wynn, Jr. | Jeffrey Jacobovitz, Karen Taylor
1/30/2013 | 12-1304 | Community State Bank v. Tommy Knox | William B. Traxler Jr., Roger L. Gregory, Allyson K. Duncan | Thomas Myrick, J. Hartzell
1/30/2013 | 12-1290 | Peter Waldburger v. CTS Corporation | Andre M. Davis, Henry F. Floyd, Stephanie D. Thacker | Emma Maddux, Earl Holman, Daniel Tenny
1/30/2013 | 12-1189 | Shirley Westveer v. Garrison Property & Casualty I | William B. Traxler Jr., Roger L. Gregory, Allyson K. Duncan | John Wilson, Brian Casey
1/30/2013 | 12-1132 | United Marketing Solutions v. Angie Fowler | Paul V. Niemeyer, Dennis W. Shedd, G. Steven Agee | Nancy Greene, Patrick McDonald
1/30/2013 | 11-5181 | US v. Michael White | Diana Gribbon Motz, Robert B. King, Henry F. Floyd | Ruth Vernet, Christopher Romano, Gary Proctor
1/30/2013 | 12-1730 | EQT Gathering Equity, LLC v. Fountain Place, LLC | Andre M. Davis, Albert Diaz, Stephanie D. Thacker | George Partain, David Hendrickson
1/30/2013 | 12-1125 | Herbert McFadden v. Federal National Mortgage Assn | J. Harvie Wilkinson III, Barbara Milano Keenan, James A. Wynn, Jr. | Thomas Domonoske, George Kostel, Ronald Guillot Jr.
1/30/2013 | 12-6274 | US v. Michael Sanderson | Andre M. Davis, Albert Diaz, Stephanie D. Thacker | Benjamin Stepp, Jeffrey Johnson
1/29/2013 | 12-1019 | Dario Suarez-Valenzuela v. Eric Holder, Jr. | Paul V. Niemeyer, Allyson K. Duncan, Henry F. Floyd | Jesse Heath, Peter Andres, Derek Julius
1/29/2013 | 12-6316 | US v. Cornell M. Taylor | J. Harvie Wilkinson III, Diana Gribbon Motz, Stephanie D. Thacker | Diana Pereira, Jennifer Dannels
1/29/2013 | 12-6172 | Luther Ford v. Robert Stevenson, III | William B. Traxler, Jr., Roger L. Gregory, Dennis W. Shedd | Katie Croghan, Peter Rutledge, James Mabry
1/29/2013 | 12-4037 | US v. Nicole Grant | William B. Traxler, Jr., Roger L. Gregory, Dennis W. Shedd | Patrick Bryant, Robert Krask
1/29/2013 | 12-1925 | Lansdowne on the Potomac v. Openband at Lansdowne, LLC | J. Harvie Wilkinson III, Diana Gribbon Motz, Stephanie D. Thacker | Sanford Saunders Jr., Christopher Wright
1/29/2013 | 12-1518 | Grayson Consulting, Inc. v. Wachovia Securities, LLC | Robert B. King, James A. Wynn, Jr., Albert Diaz | Tucker Byrd, Stephen Ratner
1/29/2013 | 12-1500 | S. M. v. Dorel Juvenile Group Inc. | Robert B. King, James A. Wynn, Jr., Albert Diaz | James O'Keeffe IV, Jonathan Judge
1/29/2013 | 12-1357 | Painters Mill Grille, LLC v. Howard Brown | Paul V. Niemeyer, Allyson K. Duncan, Henry F. Floyd | Richard Winelander, Ramona Cotca, John Vander Woude
1/29/2013 | 12-1331 | Southern Walk at Broadlands v. Openband at Broadlands, LLC | J. Harvie Wilkinson III, Diana Gribbon Motz, Stephanie D. Thacker | Kurt Rommel, Sanford Saunders Jr.
1/29/2013 | 11-1445 | Samuel Muriithi v. Shuttle Express, Inc. | Andre M. Davis, Barbara Milano Keenan, John A. Gibney Jr. | Christopher Parlo, John Singleton Sr.
1/29/2013 | 12-1119 | Calvary Christian Center v. City of Fredericksburg, VA | Paul V. Niemeyer, Allyson K. Duncan, Henry F. Floyd | Erik Stanley, Jennifer Parrish
1/29/2013 | 11-5093 | US v. Adley Abdulwahab | William B. Traxler, Jr., Roger L. Gregory, Dennis W. Shedd | William Gonyea Jr., Jessica Brumberg
1/29/2013 | 11-4870 | US v. Jolon Carthorne, Sr. | Andre M. Davis, Barbara Milano Keenan, John A. Gibney, Jr. | Matthew Robinson, Anand Ramaswamy
1/29/2013 | 11-2344 | Jerry Anderson v. Caldwell County | Andre M. Davis, Barbara Milano Keenan, John A. Gibney, Jr. | James Morgan Jr., Robert Elliot
1/29/2013 | 11-2200 | Building Graphics, Incorporate v. Lennar Corporation | Andre M. Davis, Barbara Milano Keenan, John A. Gibney, Jr. | Kathryn Cole, Eric Stevens, Thomas Wright
1/29/2013 | 11-2157 | Office of Strategic Services v. Steven Sadeghian | Robert B. King, James A. Wynn, Jr., Albert Diaz | Terrance Reed, C. Hicks III, Joseph Luchini
1/29/2013 | 11-1929 | Ali Karimi v. Eric Holder, Jr. | Robert B. King, James A. Wynn, Jr., Albert Diaz | David Belczyk, Matthew Spurlock
1/29/2013 | 11-1599 | Stanley Ballenger v. J. Dale Owens | J. Harvie Wilkinson III, Diana Gribbon Motz, Stephanie D. Thacker | David Neal, Andrew Lindemann
1/29/2013 | 12-1322 | Central Telephone Co. of VA v. Sprint Communications Company | Paul V. Niemeyer, Allyson K. Duncan, Henry F. Floyd | Timothy Simeone, Scott Angstreich, Michael Lockerby
1/28/2013 | 12-0007 | Justin Wolfe v. Harold Clarke | Robert B. King, Allyson K. Duncan, Stephanie D. Thacker | Matthew Dullaghan, Ashley Parrish